@@ -91,9 +91,9 @@ BaseGDL* BaseGDL::Transpose( DUInt* perm)
   throw GDLException("BaseGDL::Transpose(...) called.");
 }
 
-void BaseGDL::MinMax( DLong* minE, DLong* maxE, 
-		      BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
-		      SizeT start, SizeT stop, SizeT step, DLong valIx)
+void BaseGDL::MinMax(DLong* minE, DLong* maxE,
+              BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
+              SizeT start, SizeT stop, SizeT step, DLong valIx, bool useAbs)
 {
   throw GDLException("BaseGDL::MinMax(...) called.");
 }
@@ -255,6 +255,10 @@ DLong* BaseGDL::Where( bool, SizeT&)
   throw GDLException("Operation not defined for UNDEF 4b.");
 }
 
+DByte* BaseGDL::TagWhere(SizeT&) {
+  throw GDLException("Operation not defined for UNDEF 4b.");
+}
+
 BaseGDL* BaseGDL::LogNeg()
 {
   throw GDLException("Operation not defined for UNDEF 4c.");
@@ -535,6 +539,11 @@ BaseGDL* BaseGDL::Convol( BaseGDL* kIn, BaseGDL* scaleIn, BaseGDL* bias,
 {
   throw GDLException("BaseGDL::Convol(...) called.");
 }
+BaseGDL* BaseGDL::Smooth( DLong* width, int edgeMode,
+                          bool doNan, BaseGDL* missing)
+{
+  throw GDLException("BaseGDL::Smooth(...) called.");
+}
 BaseGDL* BaseGDL::Rebin( const dimension& newDim, bool sample)
 {
   throw GDLException("BaseGDL::Rebin(...) called.");
