@@ -450,7 +450,7 @@ public:
   virtual ~BaseGDL(); // defined in basegdl.cpp
 
   BaseGDL();//: dim() {} 
-  BaseGDL(const dimension& dim_);//: dim(dim_) {} 
+  explicit BaseGDL(const dimension& dim_);//: dim(dim_) {} 
 
 
   // provide access to dim member
@@ -494,7 +494,7 @@ public:
 
   virtual void MinMax( DLong* minE, DLong* maxE, 
 		       BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
-		       SizeT start = 0, SizeT stop = 0, SizeT step = 1, DLong valIx = -1);
+               SizeT start = 0, SizeT stop = 0, SizeT step = 1, DLong valIx = -1, bool useAbs = false);
 
   virtual void Clear();
   virtual void Construct();
@@ -545,6 +545,7 @@ public:
   virtual bool LogTrue();
   virtual bool LogTrue( SizeT ix);
   virtual DLong* Where( bool comp, SizeT& count);
+  virtual DByte* TagWhere(SizeT& count);
   virtual BaseGDL* LogNeg();
   virtual int Sgn(); // -1,0,1
   virtual bool Equal( BaseGDL*) const;
@@ -579,6 +580,8 @@ public:
  			   bool center, bool normalize, int edgeMode,
                                 bool doNan, BaseGDL* missing, bool doMissing,
                                 BaseGDL* invalid, bool doInvalid);
+  virtual BaseGDL* Smooth( DLong* width, int edgeMode,
+                                bool doNan, BaseGDL* missing);
   virtual BaseGDL* Rebin( const dimension& newDim, bool sample);
   // for STRUCT_ASSIGN
   virtual void Assign( BaseGDL* src, SizeT nEl);
