@@ -95,9 +95,9 @@ namespace lib {
   BaseGDL* strpos( EnvT* e);
   BaseGDL* strtrim( EnvT* e);
 
-  BaseGDL* where( EnvT* e);
-  BaseGDL* total( EnvT* e);
-  BaseGDL* product( EnvT* e);
+  BaseGDL* where_fun( EnvT* e);
+  BaseGDL* total_fun( EnvT* e);
+  BaseGDL* product_fun( EnvT* e);
 
   BaseGDL* n_params( EnvT* e);
   BaseGDL* keyword_set( EnvT* e);
@@ -111,6 +111,7 @@ namespace lib {
 
   BaseGDL* sort_fun( EnvT* e);
 
+  BaseGDL* SlowReliableMedian( EnvT* e);
   BaseGDL* median( EnvT* e);
 
   BaseGDL* shift_fun( EnvT* e);
@@ -123,8 +124,6 @@ namespace lib {
 
   BaseGDL* strjoin( EnvT* e);
 
-  //  BaseGDL* convol( EnvT* e);
-
   BaseGDL* rebin_fun( EnvT* e);
 
   BaseGDL* obj_class( EnvT* e);
@@ -167,7 +166,8 @@ namespace lib {
   BaseGDL* scope_traceback( EnvT* e);
   BaseGDL* scope_varfetch_value( EnvT* e); // regular library function
   BaseGDL** scope_varfetch_reference( EnvT* e); // special version for LEval()
-
+  BaseGDL* mean_fun(EnvT* e); 
+  BaseGDL* moment_fun(EnvT* e); 
 } // namespace
 
 #endif
