@@ -245,6 +245,7 @@ namespace lib {
 #endif
   }
 
+
 //   void kwtest( EnvT* e)
 //   {
 //     StackGuard<EnvStackT> guard( e->Interpreter()->CallStack());
@@ -373,10 +374,6 @@ namespace lib {
 	e->Throw("Conflicting keywords ALL_VALUE and ALL_GDL");
     }
 
-//     short* byValue = (short*) malloc( (nParam-2) * sizeof(short) );
-//     if (byValue == NULL) {
-// 	e->Throw("Internal error allocating memory for byValue");
-//     }
     vector<short> byValue(nParam-2,0);
 
     for (SizeT i=0; i<nParam-2;i++) {
@@ -408,6 +405,17 @@ namespace lib {
     }
     GDLGuard<void*,void,void> argvGuard(argv, free);
     
+    // test if we pass sufficently wide values in case some INT values are shorter than this machine's C "int".
+    bool upgrade[nParam-2];
+    bool small_int= (sizeof(DInt) < sizeof(int));
+    bool small_uint= (sizeof(DUInt) < sizeof(int)); //expendable, UInt and Int have same size!
+    for(SizeT i =2; i < nParam; i++){
+      BaseGDL* par = e->GetParDefined(i);
+      DType    pType  = par->Type();
+      upgrade[i-2]=false;
+      if ( pType==GDL_INT && small_int) upgrade[i-2]=true; //Warning(e->GetParString(i)+" is of type INT, too short to be passed to the called function, use LONG");}
+      if ( pType==GDL_UINT && small_uint) upgrade[i-2]=true; //Warning(e->GetParString(i)+" is of type UINT, too short to be passed to the called function, use ULONG");}
+    }
     // Fill argv with the parameters
 
     for(SizeT i =2; i < nParam; i++){
@@ -421,12 +429,17 @@ namespace lib {
 		);
 	    }
 
-	    if (NumericType(pType)) {
+	    if (NumericType(pType)) { //contains INT and UINT
 		if (par->Sizeof() > sizeof(void*)) {
 		    e->Throw("Parameter is larger than pointer: "
 			     + e->GetParString(i)
 		    );
 		}
+        if (upgrade[i-2]) {
+            DLong intpar=0; e->AssureLongScalarPar(i,intpar); //normally should be specialzed for UInts.
+            memcpy(&argv[i-2], (void*) &intpar, sizeof(DLong));
+        }
+        else
 		memcpy(&argv[i-2], (void*) par->DataAddr(), par->Sizeof());
 	    }
 	    else if (pType == GDL_STRING) {
@@ -442,9 +455,10 @@ namespace lib {
 	    argv[i-2] = (void*) par;
 	}
 	else {					// By reference (default)
-	    if (NumericType(pType) || pType == GDL_PTR || pType == GDL_OBJ ) {
-		argv[i-2] = (void*) par->DataAddr();
-	    }
+        if (NumericType(pType) || pType == GDL_PTR || pType == GDL_OBJ)
+        {
+          argv[i - 2] = (void*) par->DataAddr();
+        }
 	    else if (pType == GDL_STRING) {
 		argv[i-2] = (void*) ce_StringGDLtoIDL(e, par);
 	    }
@@ -548,15 +562,13 @@ namespace lib {
       }
     }
 
-    // now guarded. s. a.
-    //free(argv);
-
     // Return the return value
 
     switch (myReturnType) {
         case GDL_BYTE:      return new DByteGDL(ret.d_byte);
 			break;
-        case GDL_INT:       return new DIntGDL(ret.d_int);
+        case GDL_INT:
+          if (small_int)    return new DIntGDL(ret.d_int);
 			break;
         case GDL_LONG:      return new DLongGDL(ret.d_long);
 			break;
@@ -564,7 +576,8 @@ namespace lib {
 			break;
         case GDL_DOUBLE:    return new DDoubleGDL(ret.d_double);
 			break;
-        case GDL_UINT:      return new DUIntGDL(ret.d_uint);
+        case GDL_UINT:
+          if (small_uint)   return new DUIntGDL(ret.d_uint);
 			break;
         case GDL_ULONG:     return new DULongGDL(ret.d_ulong);
 			break;
