@@ -175,7 +175,7 @@ static	void operator delete( void *ptr);
   // for use by MIN and MAX functions
   void MinMax( DLong* minE, DLong* maxE, BaseGDL** minVal, BaseGDL** maxVal,
 	       bool omitNaN, 
-               SizeT start = 0, SizeT stop = 0, SizeT step = 1, DLong valIx = -1);
+               SizeT start = 0, SizeT stop = 0, SizeT step = 1, DLong valIx = -1, bool useAbs = false);
   
   bool EqType( const BaseGDL* r) const;
 
@@ -273,6 +273,7 @@ static	void operator delete( void *ptr);
   bool LogTrue();
   bool LogTrue( SizeT ix);
   DLong* Where( bool comp, SizeT& count);
+  DByte* TagWhere(SizeT& count);
   Data_<SpDByte>* LogNeg();
   int  Sgn(); // returns -1,0,1
   bool Equal( BaseGDL*) const;
@@ -293,6 +294,8 @@ static	void operator delete( void *ptr);
 		   bool center, bool normalize, int edgeMode,
                    bool doNan, BaseGDL* missing, bool doMissing,
                    BaseGDL* invalid, bool doInvalid);
+  BaseGDL* Smooth(DLong* width, int edgeMode,
+                   bool doNan, BaseGDL* missing);
   BaseGDL* Rebin( const dimension& newDim, bool sample);
 
   void Assign( BaseGDL* src, SizeT nEl);
@@ -465,13 +468,13 @@ static	void operator delete( void *ptr);
   SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, 
 		int minN, char fill, BaseGDL::IOMode oM = BaseGDL::DEC);
   SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, 
-			int minN, char fill, BaseGDL::Cal_IOMode oM = BaseGDL::DEFAULT);
+		 int minN, char *f, BaseGDL::Cal_IOMode oM = BaseGDL::DEFAULT);
   // formatting input functions
   SizeT IFmtA( std::istream* is, SizeT offset, SizeT num, int width); 
   SizeT IFmtF( std::istream* is, SizeT offs, SizeT num, int width); 
   SizeT IFmtI( std::istream* is, SizeT offs, SizeT num, int width, 
 		BaseGDL::IOMode oM = BaseGDL::DEC);
-
+  SizeT IFmtCal( std::istream* is, SizeT offs, SizeT r, int width, BaseGDL::Cal_IOMode cMode);
 #ifdef USE_PYTHON
 public:
   PyObject* ToPython();
