@@ -123,7 +123,8 @@ public:
   GDLWidgetDraw* draw = new GDLWidgetDraw(base->WidgetID(), NULL, wIx, xleng, yleng, -1, -1, false, 0);
   base->setWindow(static_cast<GDLDrawPanel*>(draw->GetWxWidget()));
   base->Realize(!hide); //just avoid to map the widget.
-  if(hide) winList[ wIx]->UnMapWindow(); //needed: will set the "pixmap" property
+  if(hide) winList[ wIx]->UnMapWindow();   //needed: will set the "pixmap" property
+ // else { winList[ wIx]->UnsetFocus(); winList[wIx]->Raise();}
   return true;
  }
 
@@ -241,9 +242,8 @@ public:
     BaseGDL* GetFontnames(){
         TidyWindowsList();
         if (actWin == -1) {
-          this->GetStream(true); //this command SHOULD NOT open a window if none opened, but how to do it?
+          this->GetStream();
           BaseGDL* val=winList[actWin]->GetFontnames(fontname);
-          WDelete(actWin);
           return val;
         } else {
           return winList[actWin]->GetFontnames(fontname);
@@ -252,9 +252,8 @@ public:
     DLong GetFontnum(){
         TidyWindowsList();
         if (actWin == -1) {
-          this->GetStream(true); //this command SHOULD NOT open a window if none opened, but how to do it?
+          this->GetStream(); 
           DLong val=winList[actWin]->GetFontnum(fontname);
-          WDelete(actWin);
           return val;
         } else {
           return winList[actWin]->GetFontnum(fontname);
@@ -311,6 +310,27 @@ public:
     SetActWin( wIx);
     return true; 
   } // GUIOpen
+    
+bool SetCharacterSize( DLong x, DLong y)     {
+   DStructGDL* dStruct=SysVar::D();
+   int tagx = dStruct->Desc()->TagIndex( "X_CH_SIZE");
+   int tagy = dStruct->Desc()->TagIndex( "Y_CH_SIZE");
+   DLongGDL* newxch = static_cast<DLongGDL*>( dStruct->GetTag( tagx));
+   DLongGDL* newych = static_cast<DLongGDL*>( dStruct->GetTag( tagy));
+   (*newxch)[0]=x;
+   (*newych)[0]=y;
+
+   int tagxppcm = dStruct->Desc()->TagIndex( "X_PX_CM");
+   int tagyppcm = dStruct->Desc()->TagIndex( "Y_PX_CM");
+   DFloat xppm = (*static_cast<DFloatGDL*>(dStruct->GetTag(tagxppcm)))[0]*0.1;
+   DFloat yppm = (*static_cast<DFloatGDL*>(dStruct->GetTag(tagyppcm)))[0]*0.1;
+
+   PLFLT newsize=x/xppm/1.5; //1.5 is probably due to height / width ratio . 
+   PLFLT newSpacing=y/yppm;
+   GDLGStream* actStream=GetStream(false);
+   if( actStream != NULL) {actStream->setLineSpacing(newSpacing); actStream->RenewPlplotDefaultCharsize(newsize);}
+   return true;
+  }
 
 //Please find how to specialize TidyWindowsList for wx and x11 widgets when this function is called
 //as GraphicsDevice::GetDevice()->TidyWindowsList(); which does not return a specialized version.
