@@ -65,7 +65,18 @@ public:
             decomposed = (Depth >= 15 ? 1 : 0);
           } 
         }
-
+        Visual *visual=DefaultVisual( display, DefaultScreen(display) ); 
+        switch ( visual->c_class )
+        {
+         case TrueColor:
+         case StaticColor:
+         case StaticGray:
+          staticDisplay=1;
+             break; //ok, are static
+         default: //dynamic: problems if cmaps not initialized.
+          staticDisplay=0;
+        }
+ 
         dStruct = new DStructGDL("!DEVICE");
         dStruct->InitTag("NAME",       DStringGDL(name));
         dStruct->InitTag("X_SIZE",     DLongGDL(640));
@@ -131,13 +142,13 @@ public:
     }
     //apparently this is OK to get same results as IDL on X11...
     yoff+=1;
-    xp=1;
-    yp=1;
+    xp=(*static_cast<DFloatGDL*>( dStruct->GetTag(dStruct->Desc()->TagIndex("X_PX_CM"))))[0]*2.5;
+    yp=(*static_cast<DFloatGDL*>( dStruct->GetTag(dStruct->Desc()->TagIndex("Y_PX_CM"))))[0]*2.5;
     
     winList[ wIx] = new GDLXStream( xleng, yleng);
     
     oList[ wIx]   = oIx++;    
-    winList[ wIx]->spage( xp, yp, xleng, yleng, xoff, yoff); //must be before 'Init'
+    winList[ wIx]->spage( xp , yp, xleng, yleng, xoff, yoff); //must be before 'Init'
 
     // no pause on win destruction
     winList[ wIx]->spause( false);
@@ -148,12 +159,22 @@ public:
     // we want color
     winList[ wIx]->scolor( 1);
 
+    //if plplot uses a non-staticColor device [TrueColor, StaticColor, StaticGray] 
+    //(because it does not ask for a static even if it exists), we must initialize here colormaps
+    //otherwise our direct X11 color commands work well and are faster than plplot's.
+    if (!this->isStatic()){
+     PLINT r[ctSize], g[ctSize], b[ctSize];
+     GDLCT* myCT=GraphicsDevice::GetGUIDevice( )->GetCT();
+     myCT->Get( r, g, b);
+     winList[ wIx]->scmap0( r, g, b, ctSize); //set colormap 0 to 256 values
+    }
+
     // window title
     static char buf[ 256];
     strncpy( buf, title.c_str(), 255);
     buf[ 255] = 0;
 //    winList[ wIx]->setopt( "db", 0); //handled elsewhere
-//    winList[ wIx]->setopt( "debug", 0);
+//    winList[ wIx]->SETOPT( "debug", "1"); //useful for debugging plplot!
     winList[ wIx]->SETOPT( "plwindow", buf);
 // Do not init colors --- we handle colors ourseves, very much faster!
     winList[ wIx]->SETOPT( "drvopt","noinitcolors=1");
@@ -175,11 +196,11 @@ public:
     winList[ wIx]->vpor(0,1,0,1);
     winList[ wIx]->wind(0,1,0,1);
     winList[ wIx]->DefaultCharSize();
-    //in case these are not initalized, here is a good place to do it.
-    if (winList[ wIx]->updatePageInfo()==true)
-    {
-      winList[ wIx]->GetPlplotDefaultCharSize(); //initializes everything in fact..
-    }
+//    //in case these are not initalized, here is a good place to do it.
+//    if (winList[ wIx]->updatePageInfo()==true)
+//    {
+//      winList[ wIx]->GetPlplotDefaultCharSize(); //initializes everything in fact..
+//    }
     // sets actWin and updates !D
     SetActWin( wIx);
     bool success;
@@ -303,9 +324,8 @@ public:
     BaseGDL* GetFontnames(){
         TidyWindowsList();
         if (actWin == -1) {
-          this->GetStream(true); //this command SHOULD NOT open a window if none opened, but how to do it?
+          this->GetStream();
           BaseGDL* val=winList[actWin]->GetFontnames(fontname);
-          WDelete(actWin);
           return val;
         } else {
           return winList[actWin]->GetFontnames(fontname);
@@ -314,9 +334,8 @@ public:
     DLong GetFontnum(){
         TidyWindowsList();
         if (actWin == -1) {
-          this->GetStream(true); //this command SHOULD NOT open a window if none opened, but how to do it?
+          this->GetStream();
           DLong val=winList[actWin]->GetFontnum(fontname);
-          WDelete(actWin);
           return val;
         } else {
           return winList[actWin]->GetFontnum(fontname);
