@@ -227,7 +227,7 @@ return Buf();
   // for use by MIN and MAX functions
   void MinMax( DLong* minE, DLong* maxE, 
 	       BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
-	       SizeT start, SizeT stop, SizeT step, DLong valIx);
+           SizeT start, SizeT stop, SizeT step, DLong valIx, bool useAbs);
 
   //  const DType   Type()    const { return SpDStruct::t;}
   //  const std::string& TypeStr() const { return SpDStruct::str;}
@@ -244,7 +244,7 @@ return Buf();
   { 
     return (Sizeof() * N_Elements());
   }
-  SizeT ToTransfer() const // number of elements for IO tranfer  
+  SizeT ToTransfer() const // number of elements for IO transfer  
   { 
     SizeT nB = 0;
     SizeT nTags=NTags();
@@ -254,6 +254,20 @@ return Buf();
       }
     return ( nB * N_Elements()); // *** error for string?
   }
+SizeT NBytesToTransfer() // number of elements for IO transfer without padding 
+{ 
+  SizeT nB = 0;
+  SizeT nTags=this->NTags();
+  for( SizeT j=0; j < this->N_Elements(); j++) { //eventually with no error for variable-length strings (in output, input will never work)
+    for( SizeT i=0; i < nTags; i++)
+    {
+      if (this->GetTag(i,j)->Type()==GDL_STRUCT) {
+        DStructGDL* str= static_cast<DStructGDL*>(this->GetTag( i, j));
+        nB += str->NBytesToTransfer();} else nB += this->GetTag( i, j)->NBytes();
+    }
+  }
+  return nB ;
+}
   SizeT Sizeof() const
   {
     return Desc()->NBytes();
@@ -265,7 +279,16 @@ return Buf();
 //       }
 //     return nB;
   }
-
+  SizeT SizeofTags() const
+  {
+     SizeT nB = 0;
+     SizeT nTags=NTags();
+     for( SizeT i=0; i < nTags; i++)
+       {
+ 	       nB += this->GetTag(i)->NBytes();
+       }
+     return nB;
+  }
 private:
   void ClearTag( SizeT t)
   {
@@ -398,6 +421,7 @@ public:
   std::ostream& ToStream(std::ostream& o, SizeT width = 0, SizeT* actPosPtr = NULL);
   //  std::ostream& ToStream(std::ostream& o)
   //  { o << *this; return o;}
+  std::ostream& ToStreamRaw(std::ostream& o);
 
   std::istream& FromStream(std::istream& i)
   { i >> *this; return i;}
@@ -496,7 +520,7 @@ DStructGDL* NewResult() const
   BaseGDL* Convert2( DType destTy, 
 		     BaseGDL::Convert2Mode mode = BaseGDL::CONVERT);
   
-#if defined( TEMPLATE_FRIEND_OK_) || (__GNUC__ >= 4)
+#if (defined( TEMPLATE_FRIEND_OK_) || (__GNUC__ >= 4)) && (!__clang__)
   // make all other Convert2 functions friends
   template<class Sp2>  
   friend BaseGDL* Data_<Sp2>::Convert2( DType destTy, 
@@ -535,6 +559,8 @@ DStructGDL* NewResult() const
   { throw GDLException("Struct expression not allowed in this context.");}
   DLong* Where( bool, SizeT&)
   { throw GDLException("Struct expression not allowed in this context.");}
+  DByte* TagWhere( SizeT&)
+  { throw GDLException("Struct expression not allowed in this context.");}
   Data_<SpDByte>* LogNeg()
   { throw GDLException("Struct expression not allowed in this context.");}
   int  Sgn(); // -1,0,1
@@ -694,14 +720,14 @@ DStructGDL* NewResult() const
   SizeT IFmtF( std::istream* is, SizeT offs, SizeT num, int width); 
   SizeT IFmtI( std::istream* is, SizeT offs, SizeT num, int width, 
 		BaseGDL::IOMode oM = DEC);
-
+  SizeT IFmtCal( std::istream* is, SizeT offs, SizeT r, int width, BaseGDL::Cal_IOMode cMode);
 private:
   void IFmtAll( SizeT offs, SizeT r,
 		SizeT& firstOut, SizeT& firstOffs, SizeT& tCount, SizeT& tCountOut);
   
   void OFmtAll( SizeT offs, SizeT r,
 		SizeT& firstOut, SizeT& firstOffs, SizeT& tCount, SizeT& tCountOut);
-  
+  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT r, int w, int d, char *f,  BaseGDL::Cal_IOMode oMode);   
   // inserts srcIn at ixDim
   // respects the exact structure
   // used by Assign -> old data must be freed
