@@ -1885,7 +1885,7 @@ bool *tests )
 				       p0S->Rank() == 0 ? dimension(1) : p0S->Dim()
 				       ); 
 
-      int tName = tName = res->Desc()->TagIndex("NAME");
+      int tName = res->Desc()->TagIndex("NAME");
       int tExists, tRead, tWrite, tExecute, tRegular, tDirectory, tBlockSpecial, 
 	tCharacterSpecial, tNamedPipe, tSetuid, tSetgid, tSocket, tStickyBit, 
 	tSymlink, tDanglingSymlink, tMode, tAtime, tCtime, tMtime, tSize;
