@@ -275,7 +275,7 @@ protected:
   long  alignment; //alignment of the widget
   long widgetStyle; //style (alignment code + other specific codes used as option to widgetsizer) 
   int dynamicResize; //for some widgets, will enable resizing: -1: not resizable, 0/1 resizable
-  vector<WidgetIDT> followers; //all the widgets that use me as group_leader
+  std::vector<WidgetIDT> followers; //all the widgets that use me as group_leader
 
   
 private:  
@@ -587,7 +587,7 @@ public:
 		 const DString& title,
 		 const DString& display_name,
 		 DLong xpad, DLong ypad,
-		 DLong x_scroll_size, DLong y_scroll_size, bool grid_layout, long children_alignment=wxALIGN_LEFT, long space=0, bool iscontextmenu=FALSE);
+		 DLong x_scroll_size, DLong y_scroll_size, bool grid_layout, long children_alignment=wxALIGN_LEFT, long space=0, bool iscontextmenu=false, bool isAGraphicWindow=false);
   
   ~GDLWidgetBase();
 
@@ -1256,8 +1256,8 @@ public:
       if ( selectionCol.GetCount() > 0 ) return TRUE;
       return FALSE;
   }
-  vector<wxPoint> GetSelectedDisjointCellsList(){
-      vector<wxPoint> list;
+  std::vector<wxPoint> GetSelectedDisjointCellsList(){
+      std::vector<wxPoint> list;
       wxGridCellCoordsArray cellSelection=this->GetSelectedCells();
       for( int i=0; i<cellSelection.Count(); i++ ) {
        int row = cellSelection[i].GetRow();
@@ -1396,6 +1396,7 @@ class GDLFrame : public wxFrame
 {
   enum {WINDOW_TIMER = wxID_HIGHEST, RESIZE_TIMER};
   bool mapped;
+  bool noFocus;
   wxSize frameSize;
   GDLApp* appOwner;
   GDLWidgetBase* gdlOwner;
@@ -1408,7 +1409,7 @@ class GDLFrame : public wxFrame
   friend class GDLWidgetBase;
 public:
   // ctor(s)
-  GDLFrame(GDLWidgetBase* gdlOwner_, wxWindowID id, const wxString& title, const wxPoint& pos=wxDefaultPosition);
+  GDLFrame(GDLWidgetBase* gdlOwner_, wxWindowID id, const wxString& title, const bool nofocus=false, const wxPoint& pos=wxDefaultPosition);
   ~GDLFrame();
 
   GDLApp* GetTheApp(){return appOwner;}
@@ -1416,6 +1417,7 @@ public:
   
   GDLWidgetBase* GetGDLOwner(){return gdlOwner;}
   bool IsMapped() const { return mapped;}
+  bool focusNotPermitted() const {return noFocus;}
   
   void SendWidgetTimerEvent(DDouble secs, WidgetIDT winId)
   {
@@ -1457,6 +1459,7 @@ public:
   void OnListBox( wxCommandEvent& event);
   void OnListBoxDoubleClicked( wxCommandEvent& event);
   void OnComboBox( wxCommandEvent& event);
+  void OnComboBoxTextEnter( wxCommandEvent& event);
   void OnButton( wxCommandEvent& event);
   void OnRadioButton( wxCommandEvent& event);
   void OnCheckBox( wxCommandEvent& event);
