@@ -229,7 +229,9 @@ BaseGDL* GDLXStream::GetFontnames(DString pattern) {
   return myList;
 }
 DLong GDLXStream::GetFontnum(DString pattern){
-  if (pattern.length()<=0) return -1;
+  // never occurs ...  if (pattern.length()<0) return -1;
+  if (this->GetFontnames(pattern) == NULL) return -1;
+  if (pattern.length()==0) return 0;
   return this->GetFontnames(pattern)->N_Elements();
 }
 DString GDLXStream::GetVisualName() {
@@ -347,7 +349,7 @@ void GDLXStream::Flush() {
 //  XFlush(xwd->display);
 }
 void GDLXStream::Update() {
-  XFlush(static_cast<XwDisplay *>(static_cast<XwDev *>(pls->dev)->xwd)->display);
+//  XFlush(static_cast<XwDisplay *>(static_cast<XwDev *>(pls->dev)->xwd)->display);
 }
 void GDLXStream::WarpPointer(DLong x, DLong y) {
   XwDev *dev = (XwDev *) pls->dev;
