@@ -205,7 +205,7 @@ public:
 		      int xpos, int ypos, bool hide)  { return false;}
   virtual bool WSize( int ix,
 		      int* xsize, int* ysize)           { return false;}
-  virtual bool WShow( int ix, bool show, bool iconic) { return false;}
+  virtual bool WShow( int ix, bool show, int iconic) { return false;}
   virtual bool WState( int ix)                        { return false;}
   virtual bool WDelete( int ix)                       { return false;}
   virtual int  MaxWin()                               { return 0;}
@@ -220,8 +220,8 @@ public:
   virtual void MaxXYSize(DLong *xsize, DLong *ysize) {
 							*xsize=1200, *ysize=800; return;}
   virtual DLong GetDecomposed()                       { return -1;}
-  virtual BaseGDL* GetFontnames()                     { return NULL;}
-  virtual DLong GetFontnum()                     { return -1;}
+  virtual BaseGDL* GetFontnames()                     { ThrowGDLException("DEVICE: Keyword GET_FONTNAMES not allowed for call to: DEVICE" );}//{return NULL;}
+  virtual DLong GetFontnum()                          { ThrowGDLException("DEVICE: Keyword GET_FONTNUM not allowed for call to: DEVICE" );}//{return -1;}
   virtual bool SetFont(DString f)                 {static int warning_sent=1; if (warning_sent) {Warning("SET_FONT not active for this device (FIXME)."); warning_sent=0;} return true;}
   virtual DString GetCurrentFont()                 {return NULL;}
   virtual DLong GetGraphicsFunction()                 { return -1;}
@@ -276,7 +276,27 @@ public:
   // Z buffer device
   virtual bool ZBuffering( bool yes)                  { return false;}
   virtual bool SetResolution( DLong nx, DLong ny)     { return false;}
+//  virtual bool SetCharacterSize( DLong x, DLong y)    { return false;}
+  
+  virtual bool SetCharacterSize( DLong x, DLong y)     {
+   int tagx = dStruct->Desc()->TagIndex( "X_CH_SIZE");
+   int tagy = dStruct->Desc()->TagIndex( "Y_CH_SIZE");
+   DLongGDL* newxch = static_cast<DLongGDL*>( dStruct->GetTag( tagx));
+   DLongGDL* newych = static_cast<DLongGDL*>( dStruct->GetTag( tagy));
+   (*newxch)[0]=x;
+   (*newych)[0]=y;
 
+   int tagxppcm = dStruct->Desc()->TagIndex( "X_PX_CM");
+   int tagyppcm = dStruct->Desc()->TagIndex( "Y_PX_CM");
+   DFloat xppm = (*static_cast<DFloatGDL*>(dStruct->GetTag(tagxppcm)))[0]*0.1;
+   DFloat yppm = (*static_cast<DFloatGDL*>(dStruct->GetTag(tagyppcm)))[0]*0.1;
+
+   PLFLT newsize=x/xppm;
+   PLFLT newSpacing=y/yppm;
+   GDLGStream* actStream=GetStream(false);
+   if( actStream != NULL) {actStream->setLineSpacing(newSpacing); actStream->RenewPlplotDefaultCharsize(newsize);}
+   return true;
+  }
   virtual void ClearStream( DLong bColor)
   {
     throw GDLException( "Device "+Name()+" does not support ClearStream.");
@@ -294,10 +314,12 @@ public:
     long gcFunction;
     int backingStoreMode;
     DString fontname;
+    int staticDisplay;
 
   int getCursorId(){return cursorId;}
   long getGCFunction(){return gcFunction;}
   int GetBackingStore(){return backingStoreMode;}
+  bool isStatic(){return staticDisplay==1;}
 
   static int actWin;
   static WindowListT winList;
@@ -309,7 +331,8 @@ public:
   cursorId(_cursorId),
   gcFunction(_gcFunction),
   backingStoreMode(_backingStoreMode),
-  fontname("")
+  fontname(""),
+  staticDisplay(1)
   {
       //pretty much nothing to do...
   }
@@ -330,15 +353,15 @@ public:
   bool WDelete(int wIx);
   bool WSize(int wIx, int *xSize, int *ySize);
   bool WSet(int wIx);
-  bool WShow(int ix, bool show, bool iconic);
+  bool WShow(int ix, bool show, int iconic);
   int WAddFree();
   GDLGStream* GetStreamAt(int wIx) const;
   void ChangeStreamAt(int wIx, GDLGStream* newStream);
   bool UnsetFocus();
   bool Decomposed(bool value);
   DLong GetDecomposed();
-  BaseGDL* GetFontnames(){return NULL;}
-  DLong GetFontnum(){return -1;}
+  BaseGDL* GetFontnames(){ ThrowGDLException("DEVICE: Keyword GET_FONTNAMES not allowed for call to: DEVICE" );}//{return NULL;}
+  DLong GetFontnum(){ ThrowGDLException("DEVICE: Keyword GET_FONTNUM not allowed for call to: DEVICE" );}//{return -1;}
   bool SetFont(DString f) {fontname=f; return true;}
   DString GetCurrentFont() {return fontname;}
   bool SetBackingStore(int value);
@@ -347,7 +370,24 @@ public:
   int ActWin();
   int GetNonManagedWidgetActWin(bool doTidyWindowList=true);
   bool CopyRegion(DLongGDL* me);
-  
+  virtual bool SetCharacterSize( DLong x, DLong y)     {
+   int tagx = dStruct->Desc()->TagIndex( "X_CH_SIZE");
+   int tagy = dStruct->Desc()->TagIndex( "Y_CH_SIZE");
+   DLongGDL* newxch = static_cast<DLongGDL*>( dStruct->GetTag( tagx));
+   DLongGDL* newych = static_cast<DLongGDL*>( dStruct->GetTag( tagy));
+   (*newxch)[0]=x;
+   (*newych)[0]=y;
+   WindowListT::iterator i;
+   int tagxppcm = dStruct->Desc()->TagIndex( "X_PX_CM");
+   int tagyppcm = dStruct->Desc()->TagIndex( "Y_PX_CM");
+   DFloat xppm = (*static_cast<DFloatGDL*>(dStruct->GetTag(tagxppcm)))[0]*0.1;
+   DFloat yppm = (*static_cast<DFloatGDL*>(dStruct->GetTag(tagyppcm)))[0]*0.1;
+
+   PLFLT newsize=x/xppm;
+   PLFLT newSpacing=y/yppm;
+   for (i = winList.begin(); i != winList.end(); ++i) if ((*i) != NULL) {(*i)->setLineSpacing(newSpacing); (*i)->RenewPlplotDefaultCharsize(newsize);}
+   return true;
+  }  
 };
 
 #endif
