@@ -41,6 +41,10 @@
 #include "gsl_fun.hpp"
 
 #include "convol.hpp"
+#include "smooth.hpp"
+#include "brent.hpp"
+#include "linearprogramming.hpp"
+#include "saverestore.hpp"
 
 #ifdef USE_PYTHON
 #  include "gdlpython.hpp"
@@ -63,6 +67,7 @@ void LibInit_ac(); // libinit_ac.cpp
 void LibInit_gm(); // libinit_gm.cpp
 void LibInit_ng(); // libinit_ng.cpp
 void LibInit_jp(); // libinit_jp.cpp
+void LibInit_exists(); // libinit_exists.cpp
 
 void LibInit()
 {
@@ -74,8 +79,19 @@ void LibInit()
   LibInit_gm();
   LibInit_ng(); 
   LibInit_jp();
+  LibInit_exists();
+
   const char KLISTEND[] = "";
 
+  const string restoreKey[]={ "FILENAME","DESCRIPTION","VERBOSE", KLISTEND};
+  const string restoreWarnKey[]={"NO_COMPILE", "RELAXED_STRUCTURE_ASSIGNMENT", "RESTORED_OBJECTS" , KLISTEND};
+  new DLibPro(lib::gdl_restore,string("RESTORE"),1,restoreKey,restoreWarnKey);
+  
+  const string saveKey[]={ "FILENAME","DESCRIPTION","VERBOSE","VARIABLES", "ALL", "COMM", "COMPRESS", "SYSTEM_VARIABLES",KLISTEND};
+  const string saveWarnKey[]={"EMBEDDED","ROUTINES", KLISTEND};
+  new DLibPro(lib::gdl_save,string("SAVE"),-1,saveKey,saveWarnKey);
+
+
   const string listKey[]={"EXTRACT", "LENGTH", "NO_COPY", KLISTEND};
   new DLibFunRetNew(lib::list_fun,string("LIST"),-1,listKey);
 
@@ -84,8 +100,9 @@ void LibInit()
 
   new DLibFun(lib::scope_level,string("SCOPE_LEVEL"),0);
 
-  const string scope_varfetchKey[]={"LEVEL", KLISTEND};
-  new DLibFun(lib::scope_varfetch_value,string("SCOPE_VARFETCH"),-1,scope_varfetchKey);
+  const string scope_varfetchKey[]={"LEVEL","ENTER", KLISTEND};
+  const string scope_varfetchWarnKey[]={"COMMON","REF_EXTRA", KLISTEND};
+  new DLibFun(lib::scope_varfetch_value,string("SCOPE_VARFETCH"),-1,scope_varfetchKey,scope_varfetchWarnKey);
   const string scope_tracebackKey[]={"STRUCTURE","SYSTEM", KLISTEND};
   new DLibFunRetNew(lib::scope_traceback,string("SCOPE_TRACEBACK"),0,scope_tracebackKey);
 
@@ -138,10 +155,13 @@ void LibInit()
   const string rebinKey[]={"SAMPLE",KLISTEND};
   new DLibFunRetNew(lib::rebin_fun,string("REBIN"),9,rebinKey);
 
-  const string convolKey[]={"CENTER","EDGE_TRUNCATE","EDGE_WRAP","EDGE_ZERO",
+  const string convolKey[]={"CENTER","EDGE_TRUNCATE","EDGE_WRAP","EDGE_ZERO", "EDGE_MIRROR",
 			    "BIAS","NORMALIZE","NAN", "INVALID", "MISSING",KLISTEND};
   new DLibFunRetNew(lib::convol_fun,string("CONVOL"),3,convolKey);
 
+  const string smoothKey[]={"NAN", "EDGE_MIRROR", "EDGE_WRAP","EDGE_TRUNCATE", "EDGE_ZERO", "MISSING", KLISTEND};
+  new DLibFunRetNew(lib::smooth_fun,string("SMOOTH"),2,smoothKey);
+
   const string file_searchKey[]={"COUNT","EXPAND_ENVIRONMENT","EXPAND_TILDE",
 				 "FOLD_CASE","ISSUE_ACCESS_ERROR",
 				 "MARK_DIRECTORY","NOSORT","QUOTE",
@@ -213,7 +233,13 @@ void LibInit()
 
   const string medianKey[]={"EVEN","DOUBLE","DIMENSION",KLISTEND};
   new DLibFunRetNew(lib::median,string("MEDIAN"),2,medianKey);
+
+  const string meanKey[]={"DOUBLE","DIMENSION","NAN",KLISTEND};
+  new DLibFunRetNew(lib::mean_fun,string("MEAN"),1,meanKey);
   
+  const string momentKey[]={"DOUBLE","DIMENSION","NAN","KURTOSIS","MAXMOMENT","MDEV","MEAN","SDEV","SKEWNESS","VARIANCE",KLISTEND};
+  new DLibFunRetNew(lib::moment_fun,string("MOMENT"),1,momentKey);
+
   new DLibFunRetNew(lib::transpose,string("TRANSPOSE"),2,NULL,NULL,true);
 
   new DLibPro(lib::retall,string("RETALL"));
@@ -465,13 +491,13 @@ void LibInit()
   new DLibPro(lib::strput,string("STRPUT"),3,NULL,NULL,2);
   
   const string whereKey[]={"COMPLEMENT","NCOMPLEMENT","NULL",KLISTEND};
-  new DLibFunRetNew(lib::where,string("WHERE"),2,whereKey);
+  new DLibFunRetNew(lib::where_fun,string("WHERE"),2,whereKey);
 
   const string totalKey[]={"CUMULATIVE","DOUBLE","NAN","INTEGER","PRESERVE_TYPE",KLISTEND};
-  new DLibFunRetNew(lib::total,string("TOTAL"),2,totalKey,NULL,true);
+  new DLibFunRetNew(lib::total_fun,string("TOTAL"),2,totalKey,NULL,true);
 
   const string productKey[]={"CUMULATIVE","NAN","INTEGER","PRESERVE_TYPE",KLISTEND};
-  new DLibFunRetNew(lib::product,string("PRODUCT"),2,productKey,NULL,true);
+  new DLibFunRetNew(lib::product_fun,string("PRODUCT"),2,productKey,NULL,true);
 
   new DLibFunRetNew(lib::n_params,string("N_PARAMS"),1); // IDL allows one parameter
   new DLibFunRetNew(lib::keyword_set,string("KEYWORD_SET"),1);
@@ -479,9 +505,9 @@ void LibInit()
   const string array_equalKey[]={"NO_TYPECONV",KLISTEND};
   new DLibFunRetNew(lib::array_equal,string("ARRAY_EQUAL"),2,array_equalKey,NULL,true);
   
-  const string minKey[]={"MAX","NAN","SUBSCRIPT_MAX","DIMENSION",KLISTEND};
+  const string minKey[]={"MAX","NAN","SUBSCRIPT_MAX","DIMENSION","ABSOLUTE",KLISTEND};
   new DLibFunRetNew(lib::min_fun,string("MIN"),2,minKey,NULL,true);
-  const string maxKey[]={"MIN","NAN","SUBSCRIPT_MIN","DIMENSION",KLISTEND};
+  const string maxKey[]={"MIN","NAN","SUBSCRIPT_MIN","DIMENSION","ABSOLUTE",KLISTEND};
   new DLibFunRetNew(lib::max_fun,string("MAX"),2,maxKey,NULL,true);
 
   // retConstant: structs are tricky: struct resolution depends from !PATH
@@ -554,6 +580,7 @@ void LibInit()
       "GET_WINDOW_POSITION","GET_PIXEL_DEPTH","GET_VISUAL_DEPTH","GET_VISUAL_NAME",
       "GET_WRITE_MASK", "COPY","GET_FONTNAMES","SET_FONT","GET_CURRENT_FONT","GET_FONTNUM",
       "SET_PIXEL_DEPTH", //Z
+      "SET_CHARACTER_SIZE", //(all)
       KLISTEND
     };
   const string deviceWarnKey[] = {
@@ -591,7 +618,6 @@ void LibInit()
   //"RESET_STRING", (TEK)
   //"RESOLUTION", (PCL)
   //"SET_COLORMAP",(PCL)
-  "SET_CHARACTER_SIZE", //(all)
   "SET_COLORS", //Z
   //"SET_STRING", (TEK)
   "SET_TRANSLATION", //X
@@ -611,13 +637,9 @@ void LibInit()
 
   const string usersymKey[]= 
   {
-    "FILL", KLISTEND
+    "FILL", "COLOR","THICK", KLISTEND
    };
-    const string usersymWarnKey[]= 
-  {
-    "COLOR","THICK", KLISTEND
-   };
-  new DLibPro(lib::usersym,string("USERSYM"),2, usersymKey, usersymWarnKey);
+  new DLibPro(lib::usersym,string("USERSYM"),2, usersymKey);
 
   const string plotKey[]=
     {
@@ -895,7 +917,7 @@ void LibInit()
   new DLibPro(lib::caldat, string("CALDAT"), 7);
   new DLibFunRetNew(lib::julday, string("JULDAY"), 6);
 
-  // SA: the HYBRID key is used in imsl_zerosys.pro to switch to the modif. Powell algo. 
+  // SA: the HYBRID key is used in imsl_zerosys.pro to switch to the modif. brent algo. 
   const string newtonKey[] = {"DOUBLE", "ITMAX", "TOLF", "TOLX", "HYBRID", KLISTEND };
   const string newtonWarnKey[] = {"CHECK", "STEPMAX", "TOLMIN", KLISTEND};
   new DLibFunRetNew(lib::newton_broyden, string("NEWTON"), 2, newtonKey, newtonWarnKey);
@@ -905,6 +927,19 @@ void LibInit()
   const string broydenWarnKey[] = {"CHECK", "STEPMAX", "TOLMIN",  "EPS",  KLISTEND};
   new DLibFunRetNew(lib::newton_broyden, string("BROYDEN"), 2, broydenKey, broydenWarnKey);
 
+
+  const string amoebaKey[] = {"FUNCTION_NAME", "FUNCTION_VALUE", "NCALLS", "NMAX", "P0", "SCALE" , "SIMPLEX", KLISTEND };
+  new DLibFunRetNew(lib::amoeba, string("AMOEBA"), 1, amoebaKey);
+  const string dfpminKey[] = { "DOUBLE", "EPS", "ITER", "ITMAX", "STEPMAX", "TOLX", KLISTEND };
+  new DLibPro(lib::dfpmin, string("DFPMIN"), 5, dfpminKey);
+  const string brentKey[] = { "DOUBLE", "ITER", "ITMAX", KLISTEND };
+  new DLibPro(lib::brent, string("POWELL"), 5, brentKey);
+
+  //#ifdef USE_GLPK
+  const string simplexKey[] = { "DOUBLE", "EPS", "STATUS", KLISTEND };
+  new DLibFunRetNew(lib::simplex, string("SIMPLEX"), 8, simplexKey);
+  //#endif
+
   new DLibFunRetNew(lib::parse_url, string("PARSE_URL"), 1);
   new DLibFunRetNew(lib::locale_get, string("LOCALE_GET"), 0);
   new DLibFunRetNew(lib::get_login_info, string("GET_LOGIN_INFO"), 0);
