@@ -61,6 +61,8 @@
 #include "gshhs.hpp"
 #endif
 
+#include "triangulation.hpp"
+
 using namespace std;
 
 void LibInit_jmg()
@@ -114,7 +116,7 @@ void LibInit_jmg()
   new DLibFunRetNew(lib::AC_invert_fun,string("INVERT"),2,invertKey);
 
   // if FFTw not available, FFT in the GSL used (slower)
-  const string fftKey[]={"DOUBLE","INVERSE","OVERWRITE","DIMENSION",KLISTEND};
+  const string fftKey[]={"DOUBLE","INVERSE","OVERWRITE","DIMENSION","CENTER",KLISTEND};
 #if defined(USE_FFTW)
   new DLibFun(lib::fftw_fun,string("FFT"),2,fftKey);
 #else
@@ -122,7 +124,7 @@ void LibInit_jmg()
 #endif
 
   const string randomKey[]={"DOUBLE","GAMMA","LONG","NORMAL",
-			    "BINOMIAL","POISSON","UNIFORM",KLISTEND};
+			    "BINOMIAL","POISSON","UNIFORM","ULONG",KLISTEND};
   const string randomWarnKey[]={"RAN1", KLISTEND}; //since IDL 8.2, change of random algo (we used already the good one).
   new DLibFunRetNew(lib::random_fun,string("RANDOMU"),MAXRANK+1,randomKey,randomWarnKey);
   new DLibFunRetNew(lib::random_fun,string("RANDOMN"),MAXRANK+1,randomKey,randomWarnKey);
@@ -136,7 +138,7 @@ void LibInit_jmg()
   const string histogramWarnKey[]={"L64",KLISTEND};
   new DLibFunRetNew(lib::histogram_fun,string("HISTOGRAM"),1,histogramKey,histogramWarnKey);
 
-  const string interpolateKey[]={"CUBIC","GRID","MISSING","NEAREST_NEIGHBOUR",KLISTEND};
+  const string interpolateKey[]={"CUBIC","DOUBLE","GRID","MISSING","NEAREST_NEIGHBOUR",KLISTEND};
   new DLibFunRetNew(lib::interpolate_fun,string("INTERPOLATE"),4,interpolateKey);
 
   const string la_triredKey[]={"DOUBLE","UPPER",KLISTEND};
@@ -187,26 +189,28 @@ void LibInit_jmg()
 			   "GRAY","LINEAR","NRHO","NTHETA","NX","NY",
 			   "RHO","RMIN","THETA","XMIN","YMIN",KLISTEND};
   new DLibFunRetNew(lib::radon_fun,string("RADON"),1,radonKey);
+  
+
+  const string grid_inputKey[]={"SPHERE", "POLAR", "DEGREES", "DUPLICATES", "EPSILON", "EXCLUDE", KLISTEND};
+  new DLibPro(lib::grid_input,string("GRID_INPUT"),6,grid_inputKey);
+  
+  const string triangulateKey[]={"CONNECTIVITY", "SPHERE", "DEGREES", "FVALUE",KLISTEND};
+  const string triangulateWarnKey[]={"REPEATS", "TOLERANCE",KLISTEND};
+  new DLibPro(lib::GDL_Triangulate,string("TRIANGULATE"),4,triangulateKey,triangulateWarnKey);
+
+  
 #ifdef PL_HAVE_QHULL
-  const string triangulateKey[]={"CONNECTIVITY", "SPHERE", "DEGREES", "FVALUE", "REPEATS", "TOLERANCE",KLISTEND};
-  new DLibPro(lib::triangulate,string("TRIANGULATE"),4,triangulateKey);
 
   const string qhullKey[]={"BOUNDS", "CONNECTIVITY", "DELAUNAY", "SPHERE", "VDIAGRAM" ,"VNORMALS", "VVERTICES", KLISTEND};
   new DLibPro(lib::qhull,string("QHULL"),8,qhullKey);
 
-  const string sph_scatKey[]={"BOUNDS", "BOUT", "GOUT", "GS", "NLON", "NLAT", KLISTEND};
-  new DLibFunRetNew(lib::sph_scat_fun,string("SPH_SCAT"),3,sph_scatKey);
-
-  const string grid_inputKey[]={"SPHERE", "POLAR", "DEGREES", "DUPLICATES", "EPSILON", "EXCLUDE", KLISTEND};
-  new DLibPro(lib::grid_input,string("GRID_INPUT"),6,grid_inputKey);
 
   const string qgrid3Key[]={"DELTA", "DIMENSION", "MISSING", "START", KLISTEND};
   new DLibFunRetNew(lib::qgrid3_fun,string("QGRID3"),5,qgrid3Key);
 #endif
-  const string trigridWarnKey[]={"EXTRAPOLATE", "INPUT", "QUINTIC",KLISTEND}; //not really dangerous
-  // "XGRID", "XOUT", "YGRID", "YOUT" , "SPHERE","DEGREES", should not be warnings since not implemented and dangerous 
-  const string trigridKey[]={ "MIN_VALUE","MAX_VALUE","MISSING","NX","NY","MAP",
-			     KLISTEND};
+  
+  const string trigridKey[]={"DEGREES","NX","NY","SPHERE","XGRID","XOUT","YGRID","YOUT","MAX_VALUE","MIN_VALUE","MISSING","INPUT",KLISTEND};
+  const string trigridWarnKey[]={"EXTRAPOLATE","QUINTIC",KLISTEND};
   new DLibFunRetNew(lib::trigrid_fun,string("TRIGRID"),6,trigridKey,trigridWarnKey);
 
   const string poly_2dKey[]={"CUBIC","MISSING",KLISTEND};
@@ -387,7 +391,8 @@ void LibInit_jmg()
   "GROUP_LEADER", "COMBOBOX_ADDITEM" ,"COMBOBOX_DELETEITEM" ,"COMBOBOX_INDEX", 
   "GET_DRAW_VIEW","SET_TAB_CURRENT", "UNITS","DYNAMIC_RESIZE","SET_SLIDER_MIN","SET_SLIDER_MAX",
   "X_BITMAP_EXTRA",KLISTEND};
-  const string widget_WarnControlKey[] ={"DELAY_DESTROY", "DEFAULT_FONT",
+  const string widget_WarnControlKey[] ={"SET_TREE_SELECT","SET_TREE_EXPANDED","SET_TREE_INDEX",
+  "SET_TREE_BITMAP","DELAY_DESTROY", "DEFAULT_FONT",
   "PUSHBUTTON_EVENTS","TABLE_BLANK","TAB_MODE","SET_TAB_MULTILINE",KLISTEND}; //LIST NOT CLOSE!!!  
   //IMPORTANT :   
   new DLibPro(lib::widget_control,string("WIDGET_CONTROL"),1, 
@@ -435,6 +440,7 @@ void LibInit_jmg()
   "TREE_ROOT","TREE_SELECT","TREE_EXPANDED","TREE_FOLDER","TREE_INDEX","TREE_BITMAP","DROP_EVENTS","DRAGGABLE","DRAG_NOTIFY","MASK",
   "LIST_SELECT","DROPLIST_SELECT","COMBOBOX_GETTEXT",
   "TAB_NUMBER","TAB_MULTILINE","TAB_CURRENT","UPDATE",
+  "TLB_KILL_REQUEST_EVENTS","TLB_MOVE_EVENTS","TLB_SIZE_EVENTS","TLB_ICONIFY_EVENTS",
   "EVENT_FUNC","EVENT_PRO","N_CHILDREN","ALL_CHILDREN","REALIZED", "UNITS",KLISTEND};
   const string widget_infoWarnKey[]={
 //  "COLUMN_WIDTHS",
@@ -448,8 +454,8 @@ void LibInit_jmg()
 //  "SLIDER_MIN_MAX","STRING_SIZE","TABLE_ALL_EVENTS","TABLE_BACKGROUND_COLOR",
 //  "TABLE_EDITABLE","TABLE_EDIT_CELL","TABLE_FONT","TABLE_FOREGROUND_COLOR","TABLE_VIEW",
 //  "TAB_MODE","TEXT_ALL_EVENTS","TEXT_EDITABLE","TEXT_NUMBER","TEXT_OFFSET_TO_XY",
-//  "TEXT_TOP_LINE","TEXT_XY_TO_OFFSET","TLB_ICONIFY_EVENTS","TLB_KILL_REQUEST_EVENTS","TLB_MOVE_EVENTS",
-//  "TLB_SIZE_EVENTS","TOOLTIP","TRACKING_EVENTS","TREE_BITMAP","TREE_DRAG_SELECT","UPDATE","USE_TABLE_SELECT","VISIBLE",
+//  "TEXT_TOP_LINE","TEXT_XY_TO_OFFSET",
+//  "TOOLTIP","TRACKING_EVENTS","TREE_DRAG_SELECT","UPDATE","USE_TABLE_SELECT","VISIBLE",
   "TAB_MODE",KLISTEND};
   new DLibFunRetNew(lib::widget_info,string("WIDGET_INFO"),1,widget_infoKey,widget_infoWarnKey);
 //LABEL
