@@ -94,7 +94,7 @@ BaseGDL* NullGDL::Transpose( DUInt* perm)
 
 void NullGDL::MinMax( DLong* minE, DLong* maxE, 
 		      BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
-		      SizeT start, SizeT stop, SizeT step, DLong valIx)
+              SizeT start, SizeT stop, SizeT step, DLong valIx, bool useAbs)
 {
   throw GDLException("NullGDL::MinMax(...) called.");
 }
@@ -258,6 +258,11 @@ DLong* NullGDL::Where( bool, SizeT&)
   throw GDLException("Operation not defined for !NULL 4b.");
 }
 
+DByte* NullGDL::TagWhere(SizeT&)
+{
+  throw GDLException("Operation not defined for !NULL 4b.");
+}
+
 BaseGDL* NullGDL::LogNeg()
 {
   throw GDLException("Operation not defined for !NULL 4c.");
@@ -578,6 +583,11 @@ BaseGDL* NullGDL::Convol( BaseGDL* kIn, BaseGDL* scaleIn, BaseGDL* bias,
 {
   throw GDLException("NullGDL::Convol(...) called.");
 }
+BaseGDL* NullGDL::Smooth( DLong* width, int edgeMode,
+                          bool doNan, BaseGDL* missing)
+{
+  throw GDLException("NullGDL::Smooth(...) called.");
+}
 BaseGDL* NullGDL::Rebin( const dimension& newDim, bool sample)
 {
   throw GDLException("NullGDL::Rebin(...) called.");
