@@ -87,7 +87,7 @@ class NullGDL: public BaseGDL
 
   /*virtual*/ void MinMax( DLong* minE, DLong* maxE, 
 		       BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
-		       SizeT start = 0, SizeT stop = 0, SizeT step = 1, DLong valIx = -1);
+               SizeT start = 0, SizeT stop = 0, SizeT step = 1, DLong valIx = -1, bool useAbs = false);
 
   /*virtual*/ void Clear();
   /*virtual*/ void Construct();
@@ -136,6 +136,7 @@ class NullGDL: public BaseGDL
   /*virtual*/ bool LogTrue();
   /*virtual*/ bool LogTrue( SizeT ix);
   /*virtual*/ DLong* Where( bool comp, SizeT& count);
+  /*virtual*/ DByte* TagWhere( SizeT& count);
   /*virtual*/ BaseGDL* LogNeg();
   /*virtual*/ int Sgn(); // -1,0,1
   /*virtual*/ bool Equal( BaseGDL*) const;
@@ -170,6 +171,8 @@ class NullGDL: public BaseGDL
 			       bool center, bool normalize, int edgeMode,
                                bool doNan, BaseGDL* missing, bool doMissing,
                                BaseGDL* invalid, bool doInvalid);
+  /*virtual*/ BaseGDL* Smooth( DLong* width, int edgeMode,
+                               bool doNan, BaseGDL* missing);
   /*virtual*/ BaseGDL* Rebin( const dimension& newDim, bool sample);
   // for STRUCT_ASSIGN
   /*virtual*/ void Assign( BaseGDL* src, SizeT nEl);
