@@ -65,6 +65,10 @@ namespace lib
     DInt fill;
     DFloat usymx[49];
     DFloat usymy[49];
+    bool hasColor;
+    DLong color;
+    bool hasThick;
+    DFloat thick;
   };
   static LOCALUSYM localusym;
   
@@ -194,15 +198,18 @@ namespace lib
   }
 #undef EXTENDED_DEFAULT_LOGRANGE
 
-
-  //improved version of "AutoIntv" for:
+   //improved version of "AutoIntv" for:
   // 1/ better managing ranges when all the data have same value
   // 2/ mimic IDL behavior when data are all positive
   // please notice that (val_min, val_max) will be changed
   // and "epsilon" is a coefficient if "extended range" is expected
   // input: linear min and max, output: linear min and max.
 
-  PLFLT gdlAdjustAxisRange(DDouble &start, DDouble &end, bool log) {
+  // NOTE GD: this function should be rewritten, documented and tested correctly. Most often, the
+  // plots are not exactly what IDL does in the same conditions. The reasons for the choices should be
+  // clearly described in the code, to be checked by others.
+  
+  PLFLT gdlAdjustAxisRange(EnvT* e, string axis, DDouble &start, DDouble &end, bool log /* = false */, int code /* = 0 */) {
     gdlHandleUnwantedAxisValue(start, end, log);
 
     DDouble min, max;
@@ -212,7 +219,7 @@ namespace lib
       min = start;
       max = end;
       invert = FALSE;
-    } else {
+    } else { //never happens by construction!!!!!!!!!!!!!!!!!!!!!!!
       min = end;
       max = start;
       invert = TRUE;
@@ -226,12 +233,14 @@ namespace lib
       cout << "init: " << min << " " << max << endl;
     }
     // case "all below ABS((MACHAR()).xmin)"
-    if (!log && (abs(max) <= std::numeric_limits<DDouble>::min())) {
-      min = DDouble(0.);
-      max = DDouble(1.);
-      intv = (PLFLT) (2.);
-      cas = 1;
-    }
+    //needs example.
+    
+//    if (!log && (abs(max) <= -std::numeric_limits<DDouble>::max())) {
+//      min = DDouble(0.);
+//      max = DDouble(1.);
+//      intv = (PLFLT) (2.);
+//      cas = 1;
+//    }
 
     if (log) {
       min = log10(min);
@@ -261,14 +270,86 @@ namespace lib
     if (cas == 0) //rounding is not aka idl due to use of ceil and floor. TBD.
     {
       x = max - min;
-      intv = AutoIntv(x);
-      if (log) {
-        max = ceil((max / intv) * intv);
-        min = floor((min / intv) * intv);
-      } else {
-        max = ceil(max / intv) * intv;
-        min = floor(min / intv) * intv;
+      //correct this for calendar values (round to nearest year, month, etc)
+      if ( code > 0) {
+        if (code ==7 ) {
+              if(x>=366)  code=1;
+              else if(x>=32)  code=2;
+              else if(x>=1.1)  code=3;
+              else if(x*24>=1.1)  code=4;
+              else if(x*24*60>=1.1)  code=5;
+              else code=6;
+        }
+        static int monthSize[]={31,28,31,30,31,30,31,31,30,31,30,31};
+        DLong Day1,Day2 , Year1,Year2 , Hour1,Hour2 , Minute1,Minute2, MonthNum1,MonthNum2;
+        DLong idow1,icap1,idow2,icap2;
+        DDouble Seconde1,Seconde2;
+        j2ymdhms(min, MonthNum1 , Day1 , Year1 , Hour1 , Minute1, Seconde1, idow1, icap1);
+        MonthNum1++; //j2ymdhms gives back Month number in the [0-11] range for indexing month name tables. pity.
+        j2ymdhms(max, MonthNum2 , Day2 , Year2 , Hour2 , Minute2, Seconde2, idow2, icap2);
+        MonthNum2++;
+        switch(code){
+             case 1:
+               //           day mon year h m s.s
+               dateToJD(min, 1, 1, Year1, 0, 0, 0.0);
+               dateToJD(max, 1, 1, Year2+1, 0, 0, 0.0);
+              break;
+             case 2:
+               dateToJD(min, 1, MonthNum1, Year1, 0, 0, 0.0);
+               MonthNum2++;
+               if (MonthNum2 > 12) {MonthNum2-=12; Year2+=1;}
+               dateToJD(max, 1, MonthNum2, Year2, 0, 0, 0.0);
+               break;
+             case 3:
+               dateToJD(min, Day1, MonthNum1, Year1, 0, 0, 0.0);
+               Day2++;
+               if (Day2 > monthSize[MonthNum2]) {Day2-=monthSize[MonthNum2]; MonthNum2+=1;}
+               if (MonthNum2 > 12) {MonthNum2-=12; Year2+=1;}
+               dateToJD(max, Day2, MonthNum2, Year2, 0, 0, 0.0);
+               break;
+             case 4:
+               dateToJD(min, Day1, MonthNum1, Year1, Hour1, 0, 0.0);
+               Hour2++;
+               if (Hour2 > 23) {Hour2-=24; Day2+=1;}
+               if (Day2 > monthSize[MonthNum2]) {Day2-=monthSize[MonthNum2]; MonthNum2+=1;}
+               if (MonthNum2 > 12) {MonthNum2-=12; Year2+=1;}
+               dateToJD(max, Day2, MonthNum2, Year2, Hour2, 0, 0.0);
+               break;
+             case 5:
+               dateToJD(min, Day1, MonthNum1, Year1, Hour1, Minute1, 0.0);
+               Minute2++;
+               if (Minute2 > 59) {Minute2-=60; Hour2+=1;}
+               if (Hour2 > 23) {Hour2-=24; Day2+=1;}
+               if (Day2 > monthSize[MonthNum2]) {Day2-=monthSize[MonthNum2]; MonthNum2+=1;}
+               if (MonthNum2 > 12) {MonthNum2-=12; Year2+=1;}
+               dateToJD(max, Day2, MonthNum2, Year2, Hour2, Minute2, 0.0);
+               break;
+             case 6:
+               dateToJD(min, Day1, MonthNum1, Year1, Hour1, Minute1, Seconde1);
+               Seconde2++;
+               if (Seconde2 > 59) {Seconde2-=60; Minute2+=1;}
+               if (Minute2 > 59) {Minute2-=60; Hour2+=1;}
+               if (Hour2 > 23) {Hour2-=24; Day2+=1;}
+               if (Day2 > monthSize[MonthNum2]) {Day2-=monthSize[MonthNum2]; MonthNum2+=1;}
+               if (MonthNum2 > 12) {MonthNum2-=12; Year2+=1;}
+               dateToJD(max, Day2, MonthNum2, Year2, Hour2, Minute2, Seconde2);
+               break;
+             default:
+              break;
+            }
+      } 
+      else {      
+        intv = AutoIntv(x);
+        if (log) {
+          max = ceil((max / intv) * intv);
+          min = floor((min / intv) * intv);
+        } else {
+          max = ceil(max / intv) * intv;
+          min = floor(min / intv) * intv;
+        }
       }
+      
+
     }
 
     if (debug) {
@@ -279,6 +360,12 @@ namespace lib
       min = pow(10, min);
       max = pow(10, max);
     }
+
+    //check if tickinterval would make more than 59 ticks (IDL apparent limit). In which case, IDL plots only the first 59 intervals:
+    DDouble TickInterval;
+    gdlGetDesiredAxisTickInterval(e, axis, TickInterval);
+    if ( TickInterval > 0.0 ) if ((max-min)/TickInterval > 59) max=min+59.0*TickInterval;
+
     if (invert) {
       start = max;
       end = min;
@@ -286,6 +373,8 @@ namespace lib
       start = min;
       end = max;
     }
+
+
     return intv;
   }
 
@@ -299,12 +388,12 @@ namespace lib
                    PLFLT& yMB,
                    PLFLT& yMT)
   {
-    PLFLT scl=actStream->dCharLength()/actStream->xSubPageSize(); //current char length/subpage size
-    xML=xMarginL*scl; //margin as percentage of subpage
-    xMR=xMarginR*scl;
-    scl=actStream->dCharHeight()/actStream->ySubPageSize(); //current char length/subpage size
-    yMB=(yMarginB+1.85)*scl;
-    yMT=(yMarginT+1.85)*scl; //to allow subscripts and superscripts (as in IDL)
+    PLFLT sclx=actStream->dCharLength()/actStream->xSubPageSize(); //current char length/subpage size
+    xML=xMarginL*sclx; //margin as percentage of subpage
+    xMR=xMarginR*sclx;
+    PLFLT scly=actStream->dLineSpacing()/actStream->ySubPageSize(); //current char length/subpage size
+    yMB=(yMarginB)*scly;
+    yMT=(yMarginT)*scly; //to allow subscripts and superscripts (as in IDL)
 
     if ( xML+xMR>=1.0 )
     {
@@ -418,15 +507,19 @@ namespace lib
     //    cout << *xStart <<" "<< *xEnd << " "<< *yStart <<" "<< *yEnd << ""<< endl;
   }
 
-  void GetUsym(DLong **n, DInt **do_fill, DFloat **x, DFloat **y)
+  void GetUsym(DLong **n, DInt **do_fill, DFloat **x, DFloat **y, bool **do_color, DLong **usymColor , bool **do_thick, DFloat **usymThick)
   {
     *n= &(localusym.nusym);
     *do_fill= &(localusym.fill);
+    *do_color= &(localusym.hasColor);
+    *do_thick= &(localusym.hasThick);
+    *usymColor=&(localusym.color);
+    *usymThick=&(localusym.thick);
     *x=localusym.usymx;
     *y=localusym.usymy;
   }
 
-  void SetUsym(DLong n, DInt do_fill, DFloat *x, DFloat *y)
+  void SetUsym(DLong n, DInt do_fill, DFloat *x, DFloat *y, bool usersymhascolor, DLong usymColor , bool usersymhasthick, DFloat usymThick )
   {
     localusym.nusym=n;
     localusym.fill=do_fill;
@@ -435,6 +528,10 @@ namespace lib
       localusym.usymx[i]=x[i];
       localusym.usymy[i]=y[i];
     }
+    localusym.hasColor=usersymhascolor;
+    localusym.hasThick=usersymhasthick;
+    localusym.color=usymColor;
+    localusym.thick=usymThick;
   }
 
   //This is the good way to get world start end end values.
@@ -571,10 +668,14 @@ namespace lib
     static PLFLT xSym[49];
     static PLFLT ySym[49];
     DInt *do_fill;
+    bool *usersymhascolor;
+    bool *usersymhasthick;
+    DLong *usymColor;
+    DFloat *usymThick;
     static DInt nofill=0;
     if ( psym_==8 )
     {
-      GetUsym(&userSymArrayDim, &do_fill, &userSymX, &userSymY);
+      GetUsym(&userSymArrayDim, &do_fill, &userSymX, &userSymY, &usersymhascolor, &usymColor , &usersymhasthick, &usymThick );
       if ( *userSymArrayDim==0 )
       {
         ThrowGDLException("No user symbol defined.");
@@ -722,7 +823,7 @@ namespace lib
             }
             else a->line(i_buff, x_buff, y_buff);
           }
-          if (psym_>0&&psym_<9)
+          if (psym_>0&&psym_<8)
           {
             for ( int j=0; j<i_buff; ++j )
             {
@@ -746,7 +847,33 @@ namespace lib
               }
             }
           }
-          if ( psym_==10 )
+        else if ( psym_==8 )
+        {
+          if (*usersymhascolor)
+          {
+            a->Color(*usymColor, decomposed);
+          }
+          if (*usersymhasthick)
+          {
+            a->Thick(*usymThick);
+          }
+          for (int j = 0; j < i_buff; ++j)
+          {
+            for (int kk = 0; kk < *userSymArrayDim; kk++)
+            {
+              xSym[kk] = x_buff[j] + userSymX[kk] * a->getPsymConvX();
+              ySym[kk] = y_buff[j] + userSymY[kk] * a->getPsymConvY();
+            }
+            if (*do_fill == 1)
+            {
+              a->fill(*userSymArrayDim, xSym, ySym);
+            } else
+            {
+              a->line(*userSymArrayDim, xSym, ySym);
+            }
+          }
+        }
+        else if ( psym_==10 )
           {
             ac_histo(a, i_buff, x_buff, y_buff, xLog);
           }
@@ -773,7 +900,7 @@ namespace lib
             }
             else a->line(i_buff, x_buff, y_buff);
         }
-        if ( psym_>0&&psym_<9 )
+        if ( psym_>0&&psym_<8 )
         {
           for ( int j=0; j<i_buff; ++j )
           {
@@ -798,7 +925,33 @@ namespace lib
           }
 
         }
-        if ( psym_==10 )
+        else if ( psym_==8 )
+        {
+          if (*usersymhascolor)
+          {
+            a->Color(*usymColor, decomposed);
+          }
+          if (*usersymhasthick)
+          {
+            a->Thick(*usymThick);
+          }
+          for (int j = 0; j < i_buff; ++j)
+          {
+            for (int kk = 0; kk < *userSymArrayDim; kk++)
+            {
+              xSym[kk] = x_buff[j] + userSymX[kk] * a->getPsymConvX();
+              ySym[kk] = y_buff[j] + userSymY[kk] * a->getPsymConvY();
+            }
+            if (*do_fill == 1)
+            {
+              a->fill(*userSymArrayDim, xSym, ySym);
+            } else
+            {
+              a->line(*userSymArrayDim, xSym, ySym);
+            }
+          }
+        }
+        else if ( psym_==10 )
         {
           ac_histo(a, i_buff, x_buff, y_buff, xLog);
         }
@@ -987,9 +1140,9 @@ namespace lib
     PLFLT p_xmin, p_xmax, p_ymin, p_ymax, norm_min, norm_max, charDim;
     actStream->gvpd(p_xmin, p_xmax, p_ymin, p_ymax); //viewport normalized coords
     DStructGDL* Struct=NULL;
-    if ( axis=="X" ) {Struct=SysVar::X(); norm_min=p_xmin; norm_max=p_xmax; charDim=actStream->nCharWidth();}
+    if ( axis=="X" ) {Struct=SysVar::X(); norm_min=p_xmin; norm_max=p_xmax; charDim=actStream->nCharLength();}
     if ( axis=="Y" ) {Struct=SysVar::Y(); norm_min=p_ymin; norm_max=p_ymax; charDim=actStream->nCharHeight();}
-    if ( axis=="Z" ) {Struct=SysVar::Z(); norm_min=0; norm_max=1; charDim=actStream->nCharWidth();}
+    if ( axis=="Z" ) {Struct=SysVar::Z(); norm_min=0; norm_max=1; charDim=actStream->nCharLength();}
     if ( Struct!=NULL )
     {
       unsigned marginTag=Struct->Desc()->TagIndex("MARGIN");
@@ -1076,62 +1229,18 @@ namespace lib
     } 
   }
 
-   void tickformat_date(PLFLT juliandate, string &Month , PLINT &Day , PLINT &Year , PLINT &Hour , PLINT &Minute, PLFLT &Second)
-    {
-    static string theMonth[12]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
-    PLFLT JD,Z,F,a;
-    PLINT A,B,C,D,E,month;
-    JD = juliandate + 0.5;
-    Z = floor(JD);
-    F = JD - Z;
-
-    if (Z < 2299161) A = (PLINT)Z;
-    else {
-      a = (PLINT) ((Z - 1867216.25) / 36524.25);
-      A = (PLINT) (Z + 1 + a - (PLINT)(a / 4));
-    }
-
-    B = A + 1524;
-    C = (PLINT) ((B - 122.1) / 365.25);
-    D = (PLINT) (365.25 * C);
-    E = (PLINT) ((B - D) / 30.6001);
-
-    // month
-    month = E < 14 ? E - 1 : E - 13;
-    Month=theMonth[month-1];
-    // day
-    Day=B - D - (PLINT)(30.6001 * E);
-    // year
-    Year = month > 1 ? C - 4716 : C - 4715; //with a zero-based index
-    if (Year < 1 ) Year--; //No Year Zero
-    // hours
-    Hour = (PLINT) (F * 24);
-    { //this prevents interpreting 04:00:00 as 03:59:60 !
-      //this kind of rounding up is explained in IDL doc.
-      DDouble FF=F+6E-10;
-      PLINT test= (PLINT) (FF * 24);
-      if (test > Hour) {Hour=test;F=FF;}
-    }
-    F -= (DDouble)Hour / 24;
-    // minutes
-    Minute = (PLINT) (F * 1440);
-    { //this prevents interpreting 04:00:00 as 03:59:60 !
-      //this kind of rounding up is explained in IDL doc.
-      DDouble FF=F+6E-10;
-      DLong test= (DLong) (FF * 1440);
-      if (test > Minute) {Minute=test;F=FF;}
-    }
-    F -= (DDouble)Minute / (DDouble)1440;
-    // seconds
-    Second = F * 86400;
-  }
-
   void doOurOwnFormat(PLINT axisNotUsed, PLFLT value, char *label, PLINT length, PLPointer data)
   {
     struct GDL_TICKDATA *ptr = (GDL_TICKDATA* )data;
-    static string normalfmt[7]={"%1.0fx10#u%d#d","%2.1fx10#u%d#d","%3.2fx10#u%d#d","%4.2fx10#u%d#d","%5.4fx10#u%d#d","%6.5fx10#u%d#d","%7.6fx10#u%d#d"};
-    static string specialfmt="10#u%d#d";
-    static string specialfmtlog="10#u%s#d";
+    //was:
+//    static string normalfmt[7]={"%1.0fx10#u%d#d","%2.1fx10#u%d#d","%3.2fx10#u%d#d","%4.2fx10#u%d#d","%5.4fx10#u%d#d","%6.5fx10#u%d#d","%7.6fx10#u%d#d"};
+//    static string specialfmt="10#u%d#d";
+//    static string specialfmtlog="10#u%s#d";
+    
+    //we need !3x!X to insure the x sign is always written in single roman.
+    static string normalfmt[7]={"%1.0f!3x!X10!E%d!N","%2.1f!3x!X10!E%d!N","%3.2f!3x!X10!E%d!N","%4.2f!3x!X10!E%d!N","%5.4f!3x!X10!E%d!N","%6.5f!3x!X10!E%d!N","%7.6f!3x!X10!E%d!N"};
+    static string specialfmt="10!E%d!N";
+    static string specialfmtlog="10!E%s!N";
     PLFLT z;
     int ns;
     char *i;
@@ -1139,7 +1248,7 @@ namespace lib
     //special cases, since plplot gives approximate zero values, not strict zeros.
     if (!(ptr->isLog) && (sgn*value<ptr->axisrange*1e-6)) 
     {
-      snprintf(label, length, "0"); 
+      snprintf(label, length, "0");
       return;
     }
     //in log, plplot gives correctly rounded "integer" values but 10^0 needs a bit of help.
@@ -1151,7 +1260,7 @@ namespace lib
     
     int e=floor(log10(value*sgn));
     char *test=(char*)calloc(2*length, sizeof(char)); //be safe
-    if (!isfinite(e)||(e<4 && e>-4)) 
+    if (!isfinite(log10(value*sgn))||(e<4 && e>-4)) 
     {
       snprintf(test, length, "%f",value);
       ns=strlen(test);
@@ -1164,9 +1273,13 @@ namespace lib
       }
       i=strrchr(test,'.'); //remove trailing '.'
       if (i==(test+ns-1)) {*i='\0'; ns--;}
-      if (ptr->isLog) snprintf( label, length, specialfmtlog.c_str(),test);
+      if (ptr->isLog) {
+        snprintf( label, length, specialfmtlog.c_str(),test);
+      }
       else
-      strncpy(label, test, length);
+      {
+        strcpy(label, test);
+      }
     }
     else
     {
@@ -1181,10 +1294,11 @@ namespace lib
         ns--;
       }
       ns-=2;ns=(ns>6)?6:ns;
-	if (floor(sgn*z)==1 && ns==0)
-	  snprintf( label, length, specialfmt.c_str(),e);
-	else
-	  snprintf( label, length, normalfmt[ns].c_str(),sgn*z,e);
+      if (floor(sgn*z)==1 && ns==0) {
+        snprintf( label, length, specialfmt.c_str(),e);
+      } else {
+        snprintf( label, length, normalfmt[ns].c_str(),sgn*z,e);
+      }
     }
     free(test);
   }
@@ -1252,16 +1366,28 @@ namespace lib
 	  }
   return res;
   }
+  //just a wrapper for doOurOwnFormat() adding general font code translation.
+  void gdlSimpleAxisTickFunc(PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data)
+  {
+    struct GDL_TICKDATA *ptr = (GDL_TICKDATA* )data;
+    doOurOwnFormat(axis, value, label, length, data);
+    //translate format codes (as in mtex).
+    double nchars;
+    std::string out = ptr->a->TranslateFormatCodes(label, &nchars);
+    ptr->nchars=max(ptr->nchars,nchars);
+    strcpy(label,out.c_str());
+  }
   
-  void gdlMultiAxisTickFunc(PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data)
+  void gdlMultiAxisTickFunc(PLINT axis, PLFLT value, char *label, PLINT length, PLPointer multiaxisdata)
   {
     static GDL_TICKDATA tdata;
     static SizeT internalIndex=0;
     static DLong lastUnits=0;
-    string Month;
-    PLINT Day , Year , Hour , Minute;
+    static string theMonth[12]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
+    PLINT Month, Day , Year , Hour , Minute, dow, cap;
     PLFLT Second;
-    struct GDL_MULTIAXISTICKDATA *ptr = (GDL_MULTIAXISTICKDATA* )data;
+    struct GDL_MULTIAXISTICKDATA *ptr = (GDL_MULTIAXISTICKDATA* )multiaxisdata;
+    tdata.a=ptr->a;
     tdata.isLog=ptr->isLog;
     if (ptr->counter != lastUnits)
     {
@@ -1273,7 +1399,6 @@ namespace lib
       if (ptr->counter > ptr->nTickFormat-1)
       {
         doOurOwnFormat(axis, value, label, length, &tdata);
-//        snprintf( label, length, "%f", value );
       }
       else
       {
@@ -1289,7 +1414,7 @@ namespace lib
           newEnv->SetNextPar( new DStringGDL(((*ptr->TickFormat)[ptr->counter]).c_str()));
           // make the call
           BaseGDL* res = static_cast<DLibFun*>(newEnv->GetPro())->Fun()(newEnv);
-          strcpy(label,(*static_cast<DStringGDL*>(res))[0].c_str()); 
+          strncpy(label,(*static_cast<DStringGDL*>(res))[0].c_str(),1000);
         }
         else // external function: if tickunits not specified, pass Axis (int), Index(int),Value(Double)
           //    else pass also Level(int)
@@ -1318,50 +1443,79 @@ namespace lib
           BaseGDL* retValGDL = e->Interpreter()->call_fun(static_cast<DSubUD*>(newEnv->GetPro())->GetTree()); 
           // we are the owner of the returned value
           Guard<BaseGDL> retGuard( retValGDL);
-          strcpy(label,(*static_cast<DStringGDL*>(retValGDL))[0].c_str()); 
+          strncpy(label,(*static_cast<DStringGDL*>(retValGDL))[0].c_str(),1000);
         }
       }
     }
-    else if (ptr->what==GDL_TICKUNITS)
+    else if (ptr->what==GDL_TICKUNITS || (ptr->what==GDL_TICKFORMAT_AND_UNITS && ptr->counter >= ptr->nTickFormat))
     {
-      if (ptr->counter > ptr->nTickUnits-1)
+      if (ptr->counter > ptr->nTickUnits-1 )
       {
         doOurOwnFormat(axis, value, label, length, &tdata);
-//        snprintf( label, length, "%f", value );
       }
       else
       {
         DString what=StrUpCase((*ptr->TickUnits)[ptr->counter]);
-        DDouble range=abs(ptr->axismax-ptr->axismin);
-        tickformat_date(value, Month , Day , Year , Hour , Minute, Second);
-        if (what.substr(0,4)=="YEAR")
-          snprintf( label, length, "%d", Year);
-        else if (what.substr(0,5)=="MONTH")
-          snprintf( label, length, "%s", Month.c_str());
-        else if (what.substr(0,3)=="DAY")
-          snprintf( label, length, "%d", Day);
-        else if (what.substr(0,4)=="HOUR")
-          snprintf( label, length, "%d", Hour);
-        else if (what.substr(0,6)=="MINUTE")
-          snprintf( label, length, "%d", Minute);
-        else if (what.substr(0,6)=="SECOND")
-          snprintf( label, length, "%f", Second);
-        else if (what.substr(0,4)=="TIME")
-        {
-          if(range>=366) snprintf( label, length, "%d", Year);
-          else if(range>=32) snprintf( label, length, "%s", Month.c_str());
-          else if(range>=1.1) snprintf( label, length, "%d", Day);
-          else if(range*24>=1.1) snprintf( label, length, "%d", Hour);
-          else if(range*24*60>=1.1) snprintf( label, length, "%d", Minute);
-          else snprintf( label, length, "%04.1f",Second);
+        if (what.length()<1) {
+          doOurOwnFormat(axis, value, label, length, &tdata);
+        }
+        else if (what.substr(0,7)=="NUMERIC") {
+          doOurOwnFormat(axis, value, label, length, &tdata);
+     } else {
+          j2ymdhms(value, Month , Day , Year , Hour , Minute, Second, dow, cap);
+          int convcode=0;
+          if (what.length()<1) convcode=7;
+          else if (what.substr(0,4)=="YEAR") convcode=1;
+          else if (what.substr(0,5)=="MONTH") convcode=2;
+          else if (what.substr(0,3)=="DAY") convcode=3;
+          else if (what.substr(0,4)=="HOUR") convcode=4;
+          else if (what.substr(0,6)=="MINUTE") convcode=5;
+          else if (what.substr(0,6)=="SECOND") convcode=6;
+          else if (what.substr(0,4)=="TIME")
+          {
+            if(ptr->axisrange>=366)  convcode=1;
+            else if(ptr->axisrange>=32)  convcode=2;
+            else if(ptr->axisrange>=1.1)  convcode=3;
+            else if(ptr->axisrange*24>=1.1)  convcode=4;
+            else if(ptr->axisrange*24*60>=1.1)  convcode=5;
+            else convcode=6;
+          } else convcode=7;
+          switch(convcode){
+            case 1:
+              snprintf( label, length, "%d", Year);
+            break;
+            case 2:
+              snprintf( label, length, "%s", theMonth[Month].c_str());
+              break;
+            case 3:
+              snprintf( label, length, "%d", Day);
+              break;
+            case 4:
+              snprintf( label, length, "%02d", Hour);
+              break;
+            case 5:
+              snprintf( label, length, "%02d", Minute);
+              break;
+            case 6:
+              snprintf( label, length, "%05.2f", Second);
+              break;
+            case 7:
+              doOurOwnFormat(axis, value, label, length, &tdata);
+              break;
+          }
+          
         }
-        else snprintf( label, length, "%g", value );
       }
     }
+    //translate format codes (as in mtex).
+    double nchars;
+    std::string out = ptr->a->TranslateFormatCodes(label, &nchars);
+    ptr->nchars=max(ptr->nchars,nchars);
+    strcpy(label,out.c_str());
     internalIndex++;
   }
 
-  void gdlSingleAxisTickFunc( PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data)
+  void gdlSingleAxisTickNamedFunc( PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data)
   {
     static GDL_TICKDATA tdata;
     struct GDL_TICKNAMEDATA *ptr = (GDL_TICKNAMEDATA* )data;
@@ -1375,6 +1529,11 @@ namespace lib
     {
       snprintf( label, length, "%s", ((*ptr->TickName)[ptr->counter]).c_str() );
     }
+    //translate format codes (as in mtex).
+    double nchars;
+    std::string out = ptr->a->TranslateFormatCodes(label, &nchars);
+    ptr->nchars=max(ptr->nchars,nchars);
+    strcpy(label,out.c_str());
     ptr->counter++;
   }
 
@@ -1391,9 +1550,13 @@ namespace lib
     Guard<BaseGDL> p0_guard;
     DLong n;
     DInt do_fill;
+    bool do_color;
+    bool do_thick;
+    DFloat thethick;
+    DLong thecolor;
     DFloat *x, *y;
     SizeT nParam=e->NParam();
-
+    if (nParam==0) e->Throw("Incorrect number of arguments.");
     if ( nParam==1 )
     {
       BaseGDL* p0=e->GetNumericArrayParDefined(0)->Transpose(NULL); //hence [49,2]
@@ -1443,359 +1606,32 @@ namespace lib
     {
       do_fill=1;
     }
-    SetUsym(n, do_fill, x, y);
+    //IDL does not complain if color is undefined.
+    do_color=false;
+    thecolor=0;
+    static int COLORIx = e->KeywordIx("COLOR");
+    if ( e->KeywordPresent(COLORIx))
+    {
+      if (e->IfDefGetKWAs<DLongGDL>( COLORIx )) {
+        e->AssureLongScalarKW(COLORIx, thecolor);
+        do_color=true;
+      }
+    }
+    //IDL does not complain if thick is undefined.
+    do_thick=false;
+    thethick=0;
+    static int THICKIx = e->KeywordIx("THICK");
+    if ( e->KeywordPresent(THICKIx))
+    {
+      if (e->IfDefGetKWAs<DFloatGDL>( THICKIx )) {
+        e->AssureFloatScalarKW(THICKIx, thethick);
+        do_thick=true;
+      }
+    }    
+    SetUsym(n, do_fill, x, y, do_color, thecolor, do_thick, thethick);
   }
   
-  BaseGDL* trigrid_fun( EnvT* e)
-  {
-    //   Compute plane parameters A,B,C given 3 points on plane.
-    //
-    //   z = A + Bx + Cy
-    //
-    //       (^x21^z10 - ^x10^z21)
-    //   C = --------------------- 
-    //       (^x21^y10 - ^x10^y21)
-    //
-    //       (^z10 - C*^y10)
-    //   B = ---------------
-    //            ^x10
-    //
-    //   A = z - Bx -Cy
-    //
-    //   where ^x21 = x2 - x1, etc.
 
-    SizeT nParam=e->NParam();
-    if( nParam < 4)
-      e->Throw( "Incorrect number of arguments.");
-
-    BaseGDL* p0 = e->GetParDefined( 0);
-    BaseGDL* p1 = e->GetParDefined( 1);
-    BaseGDL* p2 = e->GetParDefined( 2);
-    BaseGDL* p3 = e->GetParDefined( 3);
-
-    if (p0->N_Elements() != p1->N_Elements() ||
-	p0->N_Elements() != p2->N_Elements() ||
-	p1->N_Elements() != p2->N_Elements())
-      e->Throw( "X, Y, or Z array dimensions are incompatible.");
-
-    if( p3->Rank() == 0)
-      e->Throw( "Expression must be an array "
-		"in this context: "+ e->GetParString(0));
-    if (p3->N_Elements() % 3 != 0)
-      e->Throw( "Array of triangles incorrectly dimensioned.");
-    DLong n_tri = p3->N_Elements() / 3;
-
-    if( p0->Rank() == 0)
-      e->Throw( "Expression must be an array "
-		"in this context: "+ e->GetParString(0));
-    if( p0->N_Elements() < 3)
-      e->Throw( "Value of Bounds is out of allowed range.");
-
-    if( p1->Rank() == 0)
-      e->Throw( "Expression must be an array "
-		"in this context: "+ e->GetParString(1));
-
-    if( p2->Rank() == 0)
-      e->Throw( "Expression must be an array "
-		"in this context: "+ e->GetParString(2));
-
-    if (p2->Rank() < 1 || p2->Rank() > 2)
-      e->Throw( "Array must have 1 or 2 dimensions: "
-		+e->GetParString(0));
-
-    DDoubleGDL* GS=NULL;
-    DDoubleGDL* limits=NULL;
-    if( nParam > 4) {
-      BaseGDL* p4 = e->GetParDefined( 4);
-      if( p4->Rank() == 0)
-	e->Throw( "Expression must be an array "
-		  "in this context: "+ e->GetParString(4));
-      if (p4->N_Elements() != 2)
-	e->Throw( "Array must have 2 elements: "
-		  +e->GetParString(4));
-      GS = static_cast<DDoubleGDL*>
-	(p4->Convert2( GDL_DOUBLE, BaseGDL::COPY));
-
-      if( nParam == 6) {
-	BaseGDL* p5 = e->GetParDefined( 5);
-	if( p5->Rank() == 0)
-	  e->Throw( "Expression must be an array "
-		    "in this context: "+ e->GetParString(4));
-	if (p5->N_Elements() != 4)
-	  e->Throw( "Array must have 4 elements: "
-		    +e->GetParString(5));
-	limits = static_cast<DDoubleGDL*>
-	  (p5->Convert2( GDL_DOUBLE, BaseGDL::COPY));
-      }
-    }
-
-    DLong n_segx = 50;
-    DLong n_segy = 50;
-
-    DDouble diff[3][2];
-    DDouble edge[3][3];
-
-    DDouble diff_pl[3][3];
-    DDouble edge_pl[3][3];
-    DDouble uv_tri[3][3];
-    DDouble uv_gridpt[3];
-
-    DDouble delx10;
-    DDouble delx21;
-    DDouble dely10;
-    DDouble dely21;
-    DDouble delz10;
-    DDouble delz21;
-
-    DDouble A;
-    DDouble B;
-    DDouble C;
-
-    bool vertx=false;
-    bool verty=false;
-
-    DDouble lon;
-    DDouble lat;
-
-    DLong minxEl;
-    DLong maxxEl;
-    DLong minyEl;
-    DLong maxyEl;
-    
-    // Get NX, NY values if present
-    static int nxix = e->KeywordIx( "NX");
-    if(e->KeywordSet(nxix)) {
-      e->AssureLongScalarKW( nxix, n_segx);
-    }
-    static int nyix = e->KeywordIx( "NY");
-    if(e->KeywordSet(nyix)) {
-      e->AssureLongScalarKW( nyix, n_segy);
-    }
-
-    DDoubleGDL* x_tri = static_cast<DDoubleGDL*>
-      (p0->Convert2( GDL_DOUBLE, BaseGDL::COPY));
-    DDoubleGDL* y_tri = static_cast<DDoubleGDL*>
-      (p1->Convert2( GDL_DOUBLE, BaseGDL::COPY));
-    DDoubleGDL* z = static_cast<DDoubleGDL*>
-      (p2->Convert2( GDL_DOUBLE, BaseGDL::COPY));
-    DLongGDL* triangles = static_cast<DLongGDL*>
-      (p3->Convert2( GDL_LONG, BaseGDL::COPY));
-
-
-    //    bool sphere=false;
-    //int sphereix = e->KeywordIx( "SPHERE");
-    //if(e->KeywordSet(sphereix)) sphere = true;
-
-    DDouble xvsx[2];
-    DDouble yvsy[2];
-    bool map=false;
-
-#ifdef USE_LIBPROJ4
-    // Map Stuff (xtype = 3)
-
-    // Stuff needed for MAP keyword processing
-    static int mapix = e->KeywordIx( "MAP"); //trigrid_fun is standalone.
-    BaseGDL* Map = e->GetKW( mapix);
-    if( Map != NULL) {
-      if(Map->N_Elements() != 4)
-        e->Throw("Keyword array parameter MAP"
-             "must have 4 elements.");
-      map = true;
-      Guard<DDoubleGDL> guard;
-      DDoubleGDL* mapD = static_cast<DDoubleGDL*>
-        ( Map->Convert2( GDL_DOUBLE, BaseGDL::COPY));
-      guard.Reset( mapD);
-      xvsx[0] = (*mapD)[0];
-      xvsx[1] = (*mapD)[1];
-      yvsy[0] = (*mapD)[2];
-      yvsy[1] = (*mapD)[3];
-    }
-
-    LPTYPE idata;
-    XYTYPE odata;
-
-    if ( map) {
-      ref = map_init();
-      if ( ref == NULL) {
-	e->Throw( "Projection initialization failed.");
-      }
-
-      // Convert lon/lat to x/y device coord
-      for( SizeT i=0; i<x_tri->N_Elements(); ++i) {
-        idata.u = (*x_tri)[i] * DEG_TO_RAD;
-        idata.v = (*y_tri)[i] * DEG_TO_RAD;
-        odata = PJ_FWD(idata, ref);
-        (*x_tri)[i] = odata.u *  xvsx[1] + xvsx[0];
-        (*y_tri)[i] = odata.v *  yvsy[1] + yvsy[0];
-      }
-    }
-#endif
-
-    // Determine grid range
-    x_tri->MinMax( &minxEl, &maxxEl, NULL, NULL, true);
-    y_tri->MinMax( &minyEl, &maxyEl, NULL, NULL, true);
-
-    DDouble x0;
-    DDouble y0;
-    DDouble x_span = (*x_tri)[maxxEl] - (*x_tri)[minxEl];
-    DDouble y_span = (*y_tri)[maxyEl] - (*y_tri)[minyEl];
-    if (limits != NULL) {
-      x_span = (*limits)[2] - (*limits)[0];
-      y_span = (*limits)[3] - (*limits)[1];
-      x0 = (*limits)[0];
-      y0 = (*limits)[1];
-    } else {
-      x0 = (*x_tri)[minxEl];
-      y0 = (*y_tri)[minyEl];
-    }
-
-    // Determine grid spacing
-    DDouble x_spacing = x_span / n_segx;
-    DDouble y_spacing = y_span / n_segy;
-    if (GS != NULL && !e->KeywordSet(nxix)) {
-      x_spacing = (*GS)[0];
-      n_segx = (DLong) (x_span / x_spacing);
-    }
-    if (GS != NULL && !e->KeywordSet(nyix)) {
-      y_spacing = (*GS)[1];
-      n_segy = (DLong) (y_span / y_spacing);
-    }
-    if (e->KeywordSet(nxix) && n_segx == 1) n_segx = 0;
-    if (e->KeywordSet(nyix) && n_segy == 1) n_segy = 0;
-
-    // Setup return array
-    DLong dims[2];
-    dims[0] = n_segx + 1;
-    dims[1] = n_segy + 1;
-    dimension dim((DLong *) dims, 2);
-    DDoubleGDL* res = new DDoubleGDL( dim, BaseGDL::ZERO);
-
-    bool *found = new bool [(n_segx+1)*(n_segy+1)];
-    for( SizeT i=0; i<(n_segx+1)*(n_segy+1); ++i) found[i] = false;
-
-    // *** LOOP THROUGH TRIANGLES *** //
-
-    // Loop through all triangles
-    for( SizeT i=0; i<n_tri; ++i) {
-
-      DLong tri0 = (*triangles)[3*i+0];
-      DLong tri1 = (*triangles)[3*i+1];
-      DLong tri2 = (*triangles)[3*i+2];
-
-      /*
-      // Convert lon/lat to x/y device coord
-      if ( map) {
-	idata.lam = (*x_tri)[tri0] * DEG_TO_RAD;
-	idata.phi = (*y_tri)[tri0] * DEG_TO_RAD;
-	odata = pj_fwd(idata, ref);
-	(*x_tri)[tri0] = odata.x *  xvsx[1] + xvsx[0];
-	(*y_tri)[tri0] = odata.y *  yvsy[1] + yvsy[0];
-
-	idata.lam = (*x_tri)[tri1] * DEG_TO_RAD;
-	idata.phi = (*y_tri)[tri1] * DEG_TO_RAD;
-	odata = pj_fwd(idata, ref);
-	(*x_tri)[tri1] = odata.x *  xvsx[1] + xvsx[0];
-	(*y_tri)[tri1] = odata.y *  yvsy[1] + yvsy[0];
-
-	idata.lam = (*x_tri)[tri2] * DEG_TO_RAD;
-	idata.phi = (*y_tri)[tri2] * DEG_TO_RAD;
-	odata = pj_fwd(idata, ref);
-	(*x_tri)[tri2] = odata.x *  xvsx[1] + xvsx[0];
-	(*y_tri)[tri2] = odata.y *  yvsy[1] + yvsy[0];
-      }
-      */
-      // *** PLANE INTERPOLATION *** //
-
-      delx10 = (*x_tri)[tri1] - (*x_tri)[tri0];
-      delx21 = (*x_tri)[tri2] - (*x_tri)[tri1];
-
-      dely10 = (*y_tri)[tri1] - (*y_tri)[tri0];
-      dely21 = (*y_tri)[tri2] - (*y_tri)[tri1];
-
-      delz10 = (*z)[tri1] - (*z)[tri0];
-      delz21 = (*z)[tri2] - (*z)[tri1];
-	
-      // Compute grid array
-      for( SizeT j=0; j<3; ++j) {
-	DLong itri = (*triangles)[3*i+j];
-	DLong ktri = (*triangles)[3*i+((j+1) % 3)];
-	edge[j][0] = (*x_tri)[ktri] - (*x_tri)[itri];
-	edge[j][1] = (*y_tri)[ktri] - (*y_tri)[itri];
-      }
-
-      C = (delx21*delz10 - delx10*delz21) /
-	(delx21*dely10 - delx10*dely21);
-      B = (delz10 - C*dely10) / delx10;
-      A = (*z)[tri0] - B*(*x_tri)[tri0] - C*(*y_tri)[tri0];
-
-      
-      // *** LOOP THROUGH GRID POINTS *** //
-
-      // Loop through all y-grid values
-      for( SizeT iy=0; iy<n_segy+1; ++iy) {
-	DDouble devy = y0 + iy * y_spacing;
-
-	// Loop through all x-grid values
-	for( SizeT ix=0; ix<n_segx+1; ++ix) {
-
-	  if (found[iy*(n_segx+1)+ix]) continue;
-
-	  bool inside = true;
-	  DDouble devx = x0 + ix * x_spacing;
-
-	  // *** PLANE INTERPOLATION *** //
-
-	  // Compute diff array for xy-values
-	  for( SizeT j=0; j<3; ++j) {
-	    DLong itri = (*triangles)[3*i+j];
-	    diff[j][0] = (*x_tri)[itri] - devx;
-	    diff[j][1] = (*y_tri)[itri] - devy;
-	  }
-
-
-	  // Determine if inside triangle
-	  for( SizeT ivert=0; ivert<3; ++ivert) {
-	    DLong kvert = (ivert+1) % 3;
-
-	    DDouble crs1;
-	    DDouble crs2;
-	    crs1 = diff[ivert][0]*edge[ivert][1]-diff[ivert][1]*edge[ivert][0];
-	    crs2 = edge[kvert][0]*edge[ivert][1]-edge[kvert][1]*edge[ivert][0];
-	    if (crs1*crs2 > 0) {
-	      inside = false;
-	      break;
-	    }
-	  }
-
-	  if (inside == true) {
-	    found[iy*(n_segx+1)+ix] = true;
-	    (*res)[iy*(n_segx+1)+ix] = A + B*devx + C*devy;
-	    if ( map) {
-	      //	      cout << setiosflags(ios::fixed);
-	      //cout << setw(2);
-	      //cout << setprecision(2);
-	      //cout << left << "lon: "   << setw(10) << right << lon;
-	      //cout << left << "  lat: " << setw(10) << right << lat; 
-	      //cout << " in triangle: " << i << endl;
-	    }
-	  }
-
-	} // ix loop
-      } // iy loop
-    } // i (triangle) loop
-
-    for( SizeT i=0; i<(n_segx+1)*(n_segy+1); ++i) {
-      if (found[i] == false && map) {
-	//	cout << i/(n_segy+1) << " ";
-	//cout << i - (i/(n_segy+1))*(n_segy+1);
-	//cout << " NOT in triangles." << endl;
-	//(*res)[i] = 0;
-      }
-    }
-
-    delete[] found;
-    return res;
-}
 
 static DDouble bad=sqrt(-1);
   
