@@ -309,12 +309,12 @@ namespace lib
 
       if ( ( xStyle&1 )!=1 )
 	{
-	  PLFLT intv=gdlAdjustAxisRange ( xStart, xEnd, xLog );
+	  PLFLT intv=gdlAdjustAxisRange (e, "X", xStart, xEnd, xLog );
 	}
 
       if ( ( yStyle&1 )!=1 )
 	{
-	  PLFLT intv=gdlAdjustAxisRange ( yStart, yEnd, yLog );
+	  PLFLT intv=gdlAdjustAxisRange (e, "Y", yStart, yEnd, yLog );
 	}
 
       static int MIN_VALUE=e->KeywordIx("MIN_VALUE");
@@ -329,7 +329,7 @@ namespace lib
       // then only apply expansion  of axes:
       if ( ( zStyle&1 )!=1 )
 	{
-	  PLFLT intv=gdlAdjustAxisRange ( zStart, zEnd, zLog );
+	  PLFLT intv=gdlAdjustAxisRange (e, "Z", zStart, zEnd, zLog );
 	}
 
       //OVERPLOT: get stored range values instead to use them!
@@ -521,7 +521,7 @@ namespace lib
 	  else
 	    {
 	      nlevel=(PLINT) floor ( ( mapmax-mapmin )/zintv );
-	      if ( nlevel<0 ) nlevel=1; //never happens i guess
+	      if ( nlevel<=0 ) nodata=true; //yes, happens if image has constant value...
 	    }
 	  //levels values tries to be as rounded as possible aka IDL.
 
