@@ -41,7 +41,8 @@ namespace lib {
     DLong iso;
     bool doT3d;
     DFloat  UsymConvX, UsymConvY;
-
+    int calendar_codex;
+    int calendar_codey;
 private:
 
   bool handle_args(EnvT* e) 
@@ -196,15 +197,18 @@ private:
     static int xTickunitsIx = e->KeywordIx( "XTICKUNITS" );
     static int yTickunitsIx = e->KeywordIx( "YTICKUNITS" );
 
-    if ( xLog && e->KeywordSet( xTickunitsIx ) ) {
+    calendar_codex = gdlGetCalendarCode(e,"X");
+    calendar_codey = gdlGetCalendarCode(e,"Y");
+    if ( e->KeywordSet( xTickunitsIx ) && xLog) {
       Message( "PLOT: LOG setting ignored for Date/Time TICKUNITS." );
       xLog = FALSE;
     }
-    if ( yLog && e->KeywordSet( yTickunitsIx ) ) {
+    if ( e->KeywordSet( yTickunitsIx ) && yLog) {
       Message( "PLOT: LOG setting ignored for Date/Time TICKUNITS." );
       yLog = FALSE;
     }
 
+
     //    cout << xLog << " " << yLog << endl;
 
     // compute adequate values for log scale, warn adequately...
@@ -213,7 +217,7 @@ private:
     if (xLog)
     {
       DLong minEl, maxEl;
-      xVal->MinMax(&minEl, &maxEl, NULL, NULL, true);
+      xVal->MinMax(&minEl, &maxEl, NULL, NULL, true,0,xEl); //restrict minmax to xEl fist elements!!!!
       if ((*xVal)[minEl] <= 0.0) wasBadxLog = TRUE;
       xValBis = new DDoubleGDL(dimension(xEl), BaseGDL::NOZERO);
       xvalBis_guard.Reset(xValBis); // delete upon exit
@@ -223,7 +227,7 @@ private:
     if (yLog)
     {
       DLong minEl, maxEl;
-      yVal->MinMax(&minEl, &maxEl, NULL, NULL, true);
+      yVal->MinMax(&minEl, &maxEl, NULL, NULL, true,0,yEl);
       if ((*yVal)[minEl] <= 0.0) wasBadyLog = TRUE;
       yValBis = new DDoubleGDL(dimension(yEl), BaseGDL::NOZERO);
       yvalBis_guard.Reset(yValBis); // delete upon exit
@@ -234,14 +238,14 @@ private:
 #define UNDEF_RANGE_VALUE 1E-12
     {
       DLong minEl, maxEl;
-      xValBis->MinMax(&minEl, &maxEl, NULL, NULL, true);
+      xValBis->MinMax(&minEl, &maxEl, NULL, NULL, true, 0, xEl); //restrict minmax to xEl fist elements!!!!
       xStart = (*xVal)[minEl];
       xEnd = (*xVal)[maxEl];
       if (isnan(xStart)) xStart = UNDEF_RANGE_VALUE;
       if (isnan(xEnd)) xEnd = 1.0;
       if (xStart==xEnd) xStart=xEnd-UNDEF_RANGE_VALUE;
 
-      yValBis->MinMax(&minEl, &maxEl, NULL, NULL, true);
+      yValBis->MinMax(&minEl, &maxEl, NULL, NULL, true, 0, yEl);
       yStart = (*yVal)[minEl];
       yEnd = (*yVal)[maxEl];
       if (isnan(yStart)) yStart = UNDEF_RANGE_VALUE;
@@ -301,10 +305,10 @@ private:
 
      //xStyle and yStyle apply on range values
     if ((xStyle & 1) != 1) {
-      PLFLT intv = gdlAdjustAxisRange(xStart, xEnd, xLog);
+      PLFLT intv = gdlAdjustAxisRange(e, "X", xStart, xEnd, xLog, calendar_codex);
     }
     if ((yStyle & 1) != 1) {
-      PLFLT intv = gdlAdjustAxisRange(yStart, yEnd, yLog);
+      PLFLT intv = gdlAdjustAxisRange(e, "Y", yStart, yEnd, yLog, calendar_codey);
     }
 
     // MARGIN
@@ -509,7 +513,7 @@ private:
     {
       //current pen color...
       gdlSetGraphicsForegroundColorFromKw(e, actStream);
-      gdlBox(e, actStream, xStart, xEnd, yStart, yEnd, xLog, yLog);
+//      gdlBox(e, actStream, xStart, xEnd, yStart, yEnd, xLog, yLog);
     }
   } 
   
@@ -533,7 +537,8 @@ private:
 
     private: void post_call(EnvT* e, GDLGStream* actStream) 
     {
-     if (doT3d) actStream->stransform(NULL,NULL);
+      gdlBox(e, actStream, xStart, xEnd, yStart, yEnd, xLog, yLog);
+      if (doT3d) actStream->stransform(NULL,NULL);
       actStream->lsty(1);//reset linestyle
       actStream->sizeChar(1.0);
     } 
