@@ -14,14 +14,14 @@ if(p-4<v[1]) return 1;
 if(p[-1]!='o'||p[-2]!='r'||p[-3]!='p'||p[-4]!='.') return 1;
 *(p-4)=0;
 setenv("LC_COLLATE","C",1);
-setenv("GDL_PATH","+/home/marc/gdl-0.9.5/testsuite/:+/home/marc/gdl-0.9.5/src/pro/",1);
+setenv("GDL_PATH","+/home/coulais/GDL/gdl-098/gdl/testsuite/:+/home/coulais/GDL/gdl-098/gdl/src/pro/",1);
 unsetenv("GDL_STARTUP");
 unsetenv("IDL_STARTUP");
 int devnull = open("/dev/null",O_RDONLY);
 dup2(devnull, 0);
 int child_pid = fork();
 if(child_pid == 0) {
-  execl("/home/marc/gdl-0.9.5/build/src/gdl","-quiet","-e",v[1],(char*)0);
+  execl("/home/coulais/GDL/gdl-098/gdl/build/src/gdl","-quiet","-e",v[1],(char*)0);
   exit(1);
 } else {
   sched_yield();
